// Copyright IBM Corp. 2014, 2026
// SPDX-License-Identifier: BUSL-1.1

// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.36.11
// 	protoc        v5.29.3
// source: dependencies.proto

package dependencies

import (
	terraform1 "github.com/hashicorp/terraform/internal/rpcapi/terraform1"
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	reflect "reflect"
	sync "sync"
	unsafe "unsafe"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

type BuildProviderPluginCache_Event_FetchComplete_AuthResult int32

const (
	BuildProviderPluginCache_Event_FetchComplete_UNKNOWN           BuildProviderPluginCache_Event_FetchComplete_AuthResult = 0
	BuildProviderPluginCache_Event_FetchComplete_VERIFIED_CHECKSUM BuildProviderPluginCache_Event_FetchComplete_AuthResult = 1
	BuildProviderPluginCache_Event_FetchComplete_OFFICIAL_SIGNED   BuildProviderPluginCache_Event_FetchComplete_AuthResult = 2
	BuildProviderPluginCache_Event_FetchComplete_PARTNER_SIGNED    BuildProviderPluginCache_Event_FetchComplete_AuthResult = 3
	BuildProviderPluginCache_Event_FetchComplete_SELF_SIGNED       BuildProviderPluginCache_Event_FetchComplete_AuthResult = 4
)

// Enum value maps for BuildProviderPluginCache_Event_FetchComplete_AuthResult.
var (
	BuildProviderPluginCache_Event_FetchComplete_AuthResult_name = map[int32]string{
		0: "UNKNOWN",
		1: "VERIFIED_CHECKSUM",
		2: "OFFICIAL_SIGNED",
		3: "PARTNER_SIGNED",
		4: "SELF_SIGNED",
	}
	BuildProviderPluginCache_Event_FetchComplete_AuthResult_value = map[string]int32{
		"UNKNOWN":           0,
		"VERIFIED_CHECKSUM": 1,
		"OFFICIAL_SIGNED":   2,
		"PARTNER_SIGNED":    3,
		"SELF_SIGNED":       4,
	}
)

func (x BuildProviderPluginCache_Event_FetchComplete_AuthResult) Enum() *BuildProviderPluginCache_Event_FetchComplete_AuthResult {
	p := new(BuildProviderPluginCache_Event_FetchComplete_AuthResult)
	*p = x
	return p
}

func (x BuildProviderPluginCache_Event_FetchComplete_AuthResult) String() string {
	return protoimpl.X.EnumStringOf(x.Descriptor(), protoreflect.EnumNumber(x))
}

func (BuildProviderPluginCache_Event_FetchComplete_AuthResult) Descriptor() protoreflect.EnumDescriptor {
	return file_dependencies_proto_enumTypes[0].Descriptor()
}

func (BuildProviderPluginCache_Event_FetchComplete_AuthResult) Type() protoreflect.EnumType {
	return &file_dependencies_proto_enumTypes[0]
}

func (x BuildProviderPluginCache_Event_FetchComplete_AuthResult) Number() protoreflect.EnumNumber {
	return protoreflect.EnumNumber(x)
}

// Deprecated: Use BuildProviderPluginCache_Event_FetchComplete_AuthResult.Descriptor instead.
func (BuildProviderPluginCache_Event_FetchComplete_AuthResult) EnumDescriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{6, 1, 5, 0}
}

type Schema_NestedBlock_NestingMode int32

const (
	Schema_NestedBlock_INVALID Schema_NestedBlock_NestingMode = 0
	Schema_NestedBlock_SINGLE  Schema_NestedBlock_NestingMode = 1
	Schema_NestedBlock_LIST    Schema_NestedBlock_NestingMode = 2
	Schema_NestedBlock_SET     Schema_NestedBlock_NestingMode = 3
	Schema_NestedBlock_MAP     Schema_NestedBlock_NestingMode = 4
	Schema_NestedBlock_GROUP   Schema_NestedBlock_NestingMode = 5
)

// Enum value maps for Schema_NestedBlock_NestingMode.
var (
	Schema_NestedBlock_NestingMode_name = map[int32]string{
		0: "INVALID",
		1: "SINGLE",
		2: "LIST",
		3: "SET",
		4: "MAP",
		5: "GROUP",
	}
	Schema_NestedBlock_NestingMode_value = map[string]int32{
		"INVALID": 0,
		"SINGLE":  1,
		"LIST":    2,
		"SET":     3,
		"MAP":     4,
		"GROUP":   5,
	}
)

func (x Schema_NestedBlock_NestingMode) Enum() *Schema_NestedBlock_NestingMode {
	p := new(Schema_NestedBlock_NestingMode)
	*p = x
	return p
}

func (x Schema_NestedBlock_NestingMode) String() string {
	return protoimpl.X.EnumStringOf(x.Descriptor(), protoreflect.EnumNumber(x))
}

func (Schema_NestedBlock_NestingMode) Descriptor() protoreflect.EnumDescriptor {
	return file_dependencies_proto_enumTypes[1].Descriptor()
}

func (Schema_NestedBlock_NestingMode) Type() protoreflect.EnumType {
	return &file_dependencies_proto_enumTypes[1]
}

func (x Schema_NestedBlock_NestingMode) Number() protoreflect.EnumNumber {
	return protoreflect.EnumNumber(x)
}

// Deprecated: Use Schema_NestedBlock_NestingMode.Descriptor instead.
func (Schema_NestedBlock_NestingMode) EnumDescriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{14, 2, 0}
}

type Schema_Object_NestingMode int32

const (
	Schema_Object_INVALID Schema_Object_NestingMode = 0
	Schema_Object_SINGLE  Schema_Object_NestingMode = 1
	Schema_Object_LIST    Schema_Object_NestingMode = 2
	Schema_Object_SET     Schema_Object_NestingMode = 3
	Schema_Object_MAP     Schema_Object_NestingMode = 4
)

// Enum value maps for Schema_Object_NestingMode.
var (
	Schema_Object_NestingMode_name = map[int32]string{
		0: "INVALID",
		1: "SINGLE",
		2: "LIST",
		3: "SET",
		4: "MAP",
	}
	Schema_Object_NestingMode_value = map[string]int32{
		"INVALID": 0,
		"SINGLE":  1,
		"LIST":    2,
		"SET":     3,
		"MAP":     4,
	}
)

func (x Schema_Object_NestingMode) Enum() *Schema_Object_NestingMode {
	p := new(Schema_Object_NestingMode)
	*p = x
	return p
}

func (x Schema_Object_NestingMode) String() string {
	return protoimpl.X.EnumStringOf(x.Descriptor(), protoreflect.EnumNumber(x))
}

func (Schema_Object_NestingMode) Descriptor() protoreflect.EnumDescriptor {
	return file_dependencies_proto_enumTypes[2].Descriptor()
}

func (Schema_Object_NestingMode) Type() protoreflect.EnumType {
	return &file_dependencies_proto_enumTypes[2]
}

func (x Schema_Object_NestingMode) Number() protoreflect.EnumNumber {
	return protoreflect.EnumNumber(x)
}

// Deprecated: Use Schema_Object_NestingMode.Descriptor instead.
func (Schema_Object_NestingMode) EnumDescriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{14, 3, 0}
}

type Schema_DocString_Format int32

const (
	Schema_DocString_PLAIN    Schema_DocString_Format = 0
	Schema_DocString_MARKDOWN Schema_DocString_Format = 1
)

// Enum value maps for Schema_DocString_Format.
var (
	Schema_DocString_Format_name = map[int32]string{
		0: "PLAIN",
		1: "MARKDOWN",
	}
	Schema_DocString_Format_value = map[string]int32{
		"PLAIN":    0,
		"MARKDOWN": 1,
	}
)

func (x Schema_DocString_Format) Enum() *Schema_DocString_Format {
	p := new(Schema_DocString_Format)
	*p = x
	return p
}

func (x Schema_DocString_Format) String() string {
	return protoimpl.X.EnumStringOf(x.Descriptor(), protoreflect.EnumNumber(x))
}

func (Schema_DocString_Format) Descriptor() protoreflect.EnumDescriptor {
	return file_dependencies_proto_enumTypes[3].Descriptor()
}

func (Schema_DocString_Format) Type() protoreflect.EnumType {
	return &file_dependencies_proto_enumTypes[3]
}

func (x Schema_DocString_Format) Number() protoreflect.EnumNumber {
	return protoreflect.EnumNumber(x)
}

// Deprecated: Use Schema_DocString_Format.Descriptor instead.
func (Schema_DocString_Format) EnumDescriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{14, 4, 0}
}

type OpenSourceBundle struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *OpenSourceBundle) Reset() {
	*x = OpenSourceBundle{}
	mi := &file_dependencies_proto_msgTypes[0]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *OpenSourceBundle) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*OpenSourceBundle) ProtoMessage() {}

func (x *OpenSourceBundle) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[0]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use OpenSourceBundle.ProtoReflect.Descriptor instead.
func (*OpenSourceBundle) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{0}
}

type CloseSourceBundle struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *CloseSourceBundle) Reset() {
	*x = CloseSourceBundle{}
	mi := &file_dependencies_proto_msgTypes[1]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *CloseSourceBundle) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*CloseSourceBundle) ProtoMessage() {}

func (x *CloseSourceBundle) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[1]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use CloseSourceBundle.ProtoReflect.Descriptor instead.
func (*CloseSourceBundle) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{1}
}

type OpenDependencyLockFile struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *OpenDependencyLockFile) Reset() {
	*x = OpenDependencyLockFile{}
	mi := &file_dependencies_proto_msgTypes[2]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *OpenDependencyLockFile) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*OpenDependencyLockFile) ProtoMessage() {}

func (x *OpenDependencyLockFile) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[2]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use OpenDependencyLockFile.ProtoReflect.Descriptor instead.
func (*OpenDependencyLockFile) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{2}
}

type CreateDependencyLocks struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *CreateDependencyLocks) Reset() {
	*x = CreateDependencyLocks{}
	mi := &file_dependencies_proto_msgTypes[3]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *CreateDependencyLocks) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*CreateDependencyLocks) ProtoMessage() {}

func (x *CreateDependencyLocks) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[3]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use CreateDependencyLocks.ProtoReflect.Descriptor instead.
func (*CreateDependencyLocks) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{3}
}

type CloseDependencyLocks struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *CloseDependencyLocks) Reset() {
	*x = CloseDependencyLocks{}
	mi := &file_dependencies_proto_msgTypes[4]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *CloseDependencyLocks) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*CloseDependencyLocks) ProtoMessage() {}

func (x *CloseDependencyLocks) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[4]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use CloseDependencyLocks.ProtoReflect.Descriptor instead.
func (*CloseDependencyLocks) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{4}
}

type GetLockedProviderDependencies struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetLockedProviderDependencies) Reset() {
	*x = GetLockedProviderDependencies{}
	mi := &file_dependencies_proto_msgTypes[5]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetLockedProviderDependencies) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetLockedProviderDependencies) ProtoMessage() {}

func (x *GetLockedProviderDependencies) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[5]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetLockedProviderDependencies.ProtoReflect.Descriptor instead.
func (*GetLockedProviderDependencies) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{5}
}

type BuildProviderPluginCache struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *BuildProviderPluginCache) Reset() {
	*x = BuildProviderPluginCache{}
	mi := &file_dependencies_proto_msgTypes[6]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *BuildProviderPluginCache) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*BuildProviderPluginCache) ProtoMessage() {}

func (x *BuildProviderPluginCache) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[6]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use BuildProviderPluginCache.ProtoReflect.Descriptor instead.
func (*BuildProviderPluginCache) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{6}
}

type OpenProviderPluginCache struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *OpenProviderPluginCache) Reset() {
	*x = OpenProviderPluginCache{}
	mi := &file_dependencies_proto_msgTypes[7]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *OpenProviderPluginCache) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*OpenProviderPluginCache) ProtoMessage() {}

func (x *OpenProviderPluginCache) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[7]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use OpenProviderPluginCache.ProtoReflect.Descriptor instead.
func (*OpenProviderPluginCache) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{7}
}

type CloseProviderPluginCache struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *CloseProviderPluginCache) Reset() {
	*x = CloseProviderPluginCache{}
	mi := &file_dependencies_proto_msgTypes[8]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *CloseProviderPluginCache) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*CloseProviderPluginCache) ProtoMessage() {}

func (x *CloseProviderPluginCache) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[8]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use CloseProviderPluginCache.ProtoReflect.Descriptor instead.
func (*CloseProviderPluginCache) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{8}
}

type GetCachedProviders struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetCachedProviders) Reset() {
	*x = GetCachedProviders{}
	mi := &file_dependencies_proto_msgTypes[9]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetCachedProviders) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetCachedProviders) ProtoMessage() {}

func (x *GetCachedProviders) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[9]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetCachedProviders.ProtoReflect.Descriptor instead.
func (*GetCachedProviders) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{9}
}

type GetBuiltInProviders struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetBuiltInProviders) Reset() {
	*x = GetBuiltInProviders{}
	mi := &file_dependencies_proto_msgTypes[10]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetBuiltInProviders) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetBuiltInProviders) ProtoMessage() {}

func (x *GetBuiltInProviders) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[10]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetBuiltInProviders.ProtoReflect.Descriptor instead.
func (*GetBuiltInProviders) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{10}
}

type GetProviderSchema struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetProviderSchema) Reset() {
	*x = GetProviderSchema{}
	mi := &file_dependencies_proto_msgTypes[11]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetProviderSchema) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetProviderSchema) ProtoMessage() {}

func (x *GetProviderSchema) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[11]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetProviderSchema.ProtoReflect.Descriptor instead.
func (*GetProviderSchema) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{11}
}

// ProviderSchema describes the full schema for a particular provider.
type ProviderSchema struct {
	state                protoimpl.MessageState   `protogen:"open.v1"`
	ProviderConfig       *Schema                  `protobuf:"bytes,1,opt,name=provider_config,json=providerConfig,proto3" json:"provider_config,omitempty"`
	ManagedResourceTypes map[string]*Schema       `protobuf:"bytes,2,rep,name=managed_resource_types,json=managedResourceTypes,proto3" json:"managed_resource_types,omitempty" protobuf_key:"bytes,1,opt,name=key" protobuf_val:"bytes,2,opt,name=value"`
	DataResourceTypes    map[string]*Schema       `protobuf:"bytes,3,rep,name=data_resource_types,json=dataResourceTypes,proto3" json:"data_resource_types,omitempty" protobuf_key:"bytes,1,opt,name=key" protobuf_val:"bytes,2,opt,name=value"`
	ActionTypes          map[string]*ActionSchema `protobuf:"bytes,4,rep,name=action_types,json=actionTypes,proto3" json:"action_types,omitempty" protobuf_key:"bytes,1,opt,name=key" protobuf_val:"bytes,2,opt,name=value"`
	unknownFields        protoimpl.UnknownFields
	sizeCache            protoimpl.SizeCache
}

func (x *ProviderSchema) Reset() {
	*x = ProviderSchema{}
	mi := &file_dependencies_proto_msgTypes[12]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ProviderSchema) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ProviderSchema) ProtoMessage() {}

func (x *ProviderSchema) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[12]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ProviderSchema.ProtoReflect.Descriptor instead.
func (*ProviderSchema) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{12}
}

func (x *ProviderSchema) GetProviderConfig() *Schema {
	if x != nil {
		return x.ProviderConfig
	}
	return nil
}

func (x *ProviderSchema) GetManagedResourceTypes() map[string]*Schema {
	if x != nil {
		return x.ManagedResourceTypes
	}
	return nil
}

func (x *ProviderSchema) GetDataResourceTypes() map[string]*Schema {
	if x != nil {
		return x.DataResourceTypes
	}
	return nil
}

func (x *ProviderSchema) GetActionTypes() map[string]*ActionSchema {
	if x != nil {
		return x.ActionTypes
	}
	return nil
}

// ActionSchema defines the schema for an action that can be invoked by
// Terraform.
type ActionSchema struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Schema        *Schema                `protobuf:"bytes,1,opt,name=schema,proto3" json:"schema,omitempty"` // of the action itself
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ActionSchema) Reset() {
	*x = ActionSchema{}
	mi := &file_dependencies_proto_msgTypes[13]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ActionSchema) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ActionSchema) ProtoMessage() {}

func (x *ActionSchema) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[13]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ActionSchema.ProtoReflect.Descriptor instead.
func (*ActionSchema) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{13}
}

func (x *ActionSchema) GetSchema() *Schema {
	if x != nil {
		return x.Schema
	}
	return nil
}

// Schema describes a schema for an instance of a particular object, such as
// a resource type or a provider's overall configuration.
type Schema struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Block is the top level configuration block for this schema.
	Block         *Schema_Block `protobuf:"bytes,1,opt,name=block,proto3" json:"block,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *Schema) Reset() {
	*x = Schema{}
	mi := &file_dependencies_proto_msgTypes[14]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *Schema) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*Schema) ProtoMessage() {}

func (x *Schema) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[14]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use Schema.ProtoReflect.Descriptor instead.
func (*Schema) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{14}
}

func (x *Schema) GetBlock() *Schema_Block {
	if x != nil {
		return x.Block
	}
	return nil
}

type OpenSourceBundle_Request struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	LocalPath     string                 `protobuf:"bytes,1,opt,name=local_path,json=localPath,proto3" json:"local_path,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *OpenSourceBundle_Request) Reset() {
	*x = OpenSourceBundle_Request{}
	mi := &file_dependencies_proto_msgTypes[15]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *OpenSourceBundle_Request) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*OpenSourceBundle_Request) ProtoMessage() {}

func (x *OpenSourceBundle_Request) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[15]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use OpenSourceBundle_Request.ProtoReflect.Descriptor instead.
func (*OpenSourceBundle_Request) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{0, 0}
}

func (x *OpenSourceBundle_Request) GetLocalPath() string {
	if x != nil {
		return x.LocalPath
	}
	return ""
}

type OpenSourceBundle_Response struct {
	state              protoimpl.MessageState `protogen:"open.v1"`
	SourceBundleHandle int64                  `protobuf:"varint,1,opt,name=source_bundle_handle,json=sourceBundleHandle,proto3" json:"source_bundle_handle,omitempty"`
	unknownFields      protoimpl.UnknownFields
	sizeCache          protoimpl.SizeCache
}

func (x *OpenSourceBundle_Response) Reset() {
	*x = OpenSourceBundle_Response{}
	mi := &file_dependencies_proto_msgTypes[16]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *OpenSourceBundle_Response) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*OpenSourceBundle_Response) ProtoMessage() {}

func (x *OpenSourceBundle_Response) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[16]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use OpenSourceBundle_Response.ProtoReflect.Descriptor instead.
func (*OpenSourceBundle_Response) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{0, 1}
}

func (x *OpenSourceBundle_Response) GetSourceBundleHandle() int64 {
	if x != nil {
		return x.SourceBundleHandle
	}
	return 0
}

type CloseSourceBundle_Request struct {
	state              protoimpl.MessageState `protogen:"open.v1"`
	SourceBundleHandle int64                  `protobuf:"varint,1,opt,name=source_bundle_handle,json=sourceBundleHandle,proto3" json:"source_bundle_handle,omitempty"`
	unknownFields      protoimpl.UnknownFields
	sizeCache          protoimpl.SizeCache
}

func (x *CloseSourceBundle_Request) Reset() {
	*x = CloseSourceBundle_Request{}
	mi := &file_dependencies_proto_msgTypes[17]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *CloseSourceBundle_Request) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*CloseSourceBundle_Request) ProtoMessage() {}

func (x *CloseSourceBundle_Request) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[17]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use CloseSourceBundle_Request.ProtoReflect.Descriptor instead.
func (*CloseSourceBundle_Request) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{1, 0}
}

func (x *CloseSourceBundle_Request) GetSourceBundleHandle() int64 {
	if x != nil {
		return x.SourceBundleHandle
	}
	return 0
}

type CloseSourceBundle_Response struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *CloseSourceBundle_Response) Reset() {
	*x = CloseSourceBundle_Response{}
	mi := &file_dependencies_proto_msgTypes[18]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *CloseSourceBundle_Response) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*CloseSourceBundle_Response) ProtoMessage() {}

func (x *CloseSourceBundle_Response) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[18]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use CloseSourceBundle_Response.ProtoReflect.Descriptor instead.
func (*CloseSourceBundle_Response) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{1, 1}
}

type OpenDependencyLockFile_Request struct {
	state              protoimpl.MessageState    `protogen:"open.v1"`
	SourceBundleHandle int64                     `protobuf:"varint,1,opt,name=source_bundle_handle,json=sourceBundleHandle,proto3" json:"source_bundle_handle,omitempty"`
	SourceAddress      *terraform1.SourceAddress `protobuf:"bytes,2,opt,name=source_address,json=sourceAddress,proto3" json:"source_address,omitempty"`
	unknownFields      protoimpl.UnknownFields
	sizeCache          protoimpl.SizeCache
}

func (x *OpenDependencyLockFile_Request) Reset() {
	*x = OpenDependencyLockFile_Request{}
	mi := &file_dependencies_proto_msgTypes[19]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *OpenDependencyLockFile_Request) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*OpenDependencyLockFile_Request) ProtoMessage() {}

func (x *OpenDependencyLockFile_Request) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[19]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use OpenDependencyLockFile_Request.ProtoReflect.Descriptor instead.
func (*OpenDependencyLockFile_Request) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{2, 0}
}

func (x *OpenDependencyLockFile_Request) GetSourceBundleHandle() int64 {
	if x != nil {
		return x.SourceBundleHandle
	}
	return 0
}

func (x *OpenDependencyLockFile_Request) GetSourceAddress() *terraform1.SourceAddress {
	if x != nil {
		return x.SourceAddress
	}
	return nil
}

type OpenDependencyLockFile_Response struct {
	state                 protoimpl.MessageState   `protogen:"open.v1"`
	DependencyLocksHandle int64                    `protobuf:"varint,1,opt,name=dependency_locks_handle,json=dependencyLocksHandle,proto3" json:"dependency_locks_handle,omitempty"`
	Diagnostics           []*terraform1.Diagnostic `protobuf:"bytes,2,rep,name=diagnostics,proto3" json:"diagnostics,omitempty"`
	unknownFields         protoimpl.UnknownFields
	sizeCache             protoimpl.SizeCache
}

func (x *OpenDependencyLockFile_Response) Reset() {
	*x = OpenDependencyLockFile_Response{}
	mi := &file_dependencies_proto_msgTypes[20]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *OpenDependencyLockFile_Response) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*OpenDependencyLockFile_Response) ProtoMessage() {}

func (x *OpenDependencyLockFile_Response) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[20]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use OpenDependencyLockFile_Response.ProtoReflect.Descriptor instead.
func (*OpenDependencyLockFile_Response) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{2, 1}
}

func (x *OpenDependencyLockFile_Response) GetDependencyLocksHandle() int64 {
	if x != nil {
		return x.DependencyLocksHandle
	}
	return 0
}

func (x *OpenDependencyLockFile_Response) GetDiagnostics() []*terraform1.Diagnostic {
	if x != nil {
		return x.Diagnostics
	}
	return nil
}

type CreateDependencyLocks_Request struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// The provider selections to include in the locks object.
	//
	// A typical value would be the result of an earlier call to
	// GetLockedProviderDependencies on some other locks object,
	// e.g. if a caller needs to propagate a set of locks from one
	// Terraform Core RPC server to another.
	ProviderSelections []*terraform1.ProviderPackage `protobuf:"bytes,1,rep,name=provider_selections,json=providerSelections,proto3" json:"provider_selections,omitempty"`
	unknownFields      protoimpl.UnknownFields
	sizeCache          protoimpl.SizeCache
}

func (x *CreateDependencyLocks_Request) Reset() {
	*x = CreateDependencyLocks_Request{}
	mi := &file_dependencies_proto_msgTypes[21]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *CreateDependencyLocks_Request) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*CreateDependencyLocks_Request) ProtoMessage() {}

func (x *CreateDependencyLocks_Request) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[21]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use CreateDependencyLocks_Request.ProtoReflect.Descriptor instead.
func (*CreateDependencyLocks_Request) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{3, 0}
}

func (x *CreateDependencyLocks_Request) GetProviderSelections() []*terraform1.ProviderPackage {
	if x != nil {
		return x.ProviderSelections
	}
	return nil
}

type CreateDependencyLocks_Response struct {
	state                 protoimpl.MessageState `protogen:"open.v1"`
	DependencyLocksHandle int64                  `protobuf:"varint,1,opt,name=dependency_locks_handle,json=dependencyLocksHandle,proto3" json:"dependency_locks_handle,omitempty"`
	unknownFields         protoimpl.UnknownFields
	sizeCache             protoimpl.SizeCache
}

func (x *CreateDependencyLocks_Response) Reset() {
	*x = CreateDependencyLocks_Response{}
	mi := &file_dependencies_proto_msgTypes[22]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *CreateDependencyLocks_Response) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*CreateDependencyLocks_Response) ProtoMessage() {}

func (x *CreateDependencyLocks_Response) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[22]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use CreateDependencyLocks_Response.ProtoReflect.Descriptor instead.
func (*CreateDependencyLocks_Response) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{3, 1}
}

func (x *CreateDependencyLocks_Response) GetDependencyLocksHandle() int64 {
	if x != nil {
		return x.DependencyLocksHandle
	}
	return 0
}

type CloseDependencyLocks_Request struct {
	state                 protoimpl.MessageState `protogen:"open.v1"`
	DependencyLocksHandle int64                  `protobuf:"varint,1,opt,name=dependency_locks_handle,json=dependencyLocksHandle,proto3" json:"dependency_locks_handle,omitempty"`
	unknownFields         protoimpl.UnknownFields
	sizeCache             protoimpl.SizeCache
}

func (x *CloseDependencyLocks_Request) Reset() {
	*x = CloseDependencyLocks_Request{}
	mi := &file_dependencies_proto_msgTypes[23]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *CloseDependencyLocks_Request) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*CloseDependencyLocks_Request) ProtoMessage() {}

func (x *CloseDependencyLocks_Request) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[23]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use CloseDependencyLocks_Request.ProtoReflect.Descriptor instead.
func (*CloseDependencyLocks_Request) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{4, 0}
}

func (x *CloseDependencyLocks_Request) GetDependencyLocksHandle() int64 {
	if x != nil {
		return x.DependencyLocksHandle
	}
	return 0
}

type CloseDependencyLocks_Response struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *CloseDependencyLocks_Response) Reset() {
	*x = CloseDependencyLocks_Response{}
	mi := &file_dependencies_proto_msgTypes[24]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *CloseDependencyLocks_Response) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*CloseDependencyLocks_Response) ProtoMessage() {}

func (x *CloseDependencyLocks_Response) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[24]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use CloseDependencyLocks_Response.ProtoReflect.Descriptor instead.
func (*CloseDependencyLocks_Response) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{4, 1}
}

type GetLockedProviderDependencies_Request struct {
	state                 protoimpl.MessageState `protogen:"open.v1"`
	DependencyLocksHandle int64                  `protobuf:"varint,1,opt,name=dependency_locks_handle,json=dependencyLocksHandle,proto3" json:"dependency_locks_handle,omitempty"`
	unknownFields         protoimpl.UnknownFields
	sizeCache             protoimpl.SizeCache
}

func (x *GetLockedProviderDependencies_Request) Reset() {
	*x = GetLockedProviderDependencies_Request{}
	mi := &file_dependencies_proto_msgTypes[25]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetLockedProviderDependencies_Request) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetLockedProviderDependencies_Request) ProtoMessage() {}

func (x *GetLockedProviderDependencies_Request) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[25]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetLockedProviderDependencies_Request.ProtoReflect.Descriptor instead.
func (*GetLockedProviderDependencies_Request) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{5, 0}
}

func (x *GetLockedProviderDependencies_Request) GetDependencyLocksHandle() int64 {
	if x != nil {
		return x.DependencyLocksHandle
	}
	return 0
}

type GetLockedProviderDependencies_Response struct {
	state             protoimpl.MessageState        `protogen:"open.v1"`
	SelectedProviders []*terraform1.ProviderPackage `protobuf:"bytes,1,rep,name=selected_providers,json=selectedProviders,proto3" json:"selected_providers,omitempty"`
	unknownFields     protoimpl.UnknownFields
	sizeCache         protoimpl.SizeCache
}

func (x *GetLockedProviderDependencies_Response) Reset() {
	*x = GetLockedProviderDependencies_Response{}
	mi := &file_dependencies_proto_msgTypes[26]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetLockedProviderDependencies_Response) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetLockedProviderDependencies_Response) ProtoMessage() {}

func (x *GetLockedProviderDependencies_Response) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[26]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetLockedProviderDependencies_Response.ProtoReflect.Descriptor instead.
func (*GetLockedProviderDependencies_Response) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{5, 1}
}

func (x *GetLockedProviderDependencies_Response) GetSelectedProviders() []*terraform1.ProviderPackage {
	if x != nil {
		return x.SelectedProviders
	}
	return nil
}

type BuildProviderPluginCache_Request struct {
	state                 protoimpl.MessageState                            `protogen:"open.v1"`
	CacheDir              string                                            `protobuf:"bytes,1,opt,name=cache_dir,json=cacheDir,proto3" json:"cache_dir,omitempty"`
	DependencyLocksHandle int64                                             `protobuf:"varint,2,opt,name=dependency_locks_handle,json=dependencyLocksHandle,proto3" json:"dependency_locks_handle,omitempty"`
	InstallationMethods   []*BuildProviderPluginCache_Request_InstallMethod `protobuf:"bytes,3,rep,name=installation_methods,json=installationMethods,proto3" json:"installation_methods,omitempty"`
	// If set, this populates the cache with plugins for a different
	// platform than the one the Terraform Core RPC server is running on.
	// If unset (empty) then the cache will be populated with packages
	// for the same platform as Terraform Core was built for, if available.
	//
	// If this is set to a different platform than the Terraform Core RPC
	// server's then the generated cache directory will appear empty to
	// other operations on this server.
	OverridePlatform string `protobuf:"bytes,4,opt,name=override_platform,json=overridePlatform,proto3" json:"override_platform,omitempty"`
	unknownFields    protoimpl.UnknownFields
	sizeCache        protoimpl.SizeCache
}

func (x *BuildProviderPluginCache_Request) Reset() {
	*x = BuildProviderPluginCache_Request{}
	mi := &file_dependencies_proto_msgTypes[27]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *BuildProviderPluginCache_Request) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*BuildProviderPluginCache_Request) ProtoMessage() {}

func (x *BuildProviderPluginCache_Request) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[27]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use BuildProviderPluginCache_Request.ProtoReflect.Descriptor instead.
func (*BuildProviderPluginCache_Request) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{6, 0}
}

func (x *BuildProviderPluginCache_Request) GetCacheDir() string {
	if x != nil {
		return x.CacheDir
	}
	return ""
}

func (x *BuildProviderPluginCache_Request) GetDependencyLocksHandle() int64 {
	if x != nil {
		return x.DependencyLocksHandle
	}
	return 0
}

func (x *BuildProviderPluginCache_Request) GetInstallationMethods() []*BuildProviderPluginCache_Request_InstallMethod {
	if x != nil {
		return x.InstallationMethods
	}
	return nil
}

func (x *BuildProviderPluginCache_Request) GetOverridePlatform() string {
	if x != nil {
		return x.OverridePlatform
	}
	return ""
}

type BuildProviderPluginCache_Event struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Types that are valid to be assigned to Event:
	//
	//	*BuildProviderPluginCache_Event_Pending_
	//	*BuildProviderPluginCache_Event_AlreadyInstalled
	//	*BuildProviderPluginCache_Event_BuiltIn
	//	*BuildProviderPluginCache_Event_QueryBegin
	//	*BuildProviderPluginCache_Event_QuerySuccess
	//	*BuildProviderPluginCache_Event_QueryWarnings
	//	*BuildProviderPluginCache_Event_FetchBegin_
	//	*BuildProviderPluginCache_Event_FetchComplete_
	//	*BuildProviderPluginCache_Event_Diagnostic
	Event         isBuildProviderPluginCache_Event_Event `protobuf_oneof:"event"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *BuildProviderPluginCache_Event) Reset() {
	*x = BuildProviderPluginCache_Event{}
	mi := &file_dependencies_proto_msgTypes[28]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *BuildProviderPluginCache_Event) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*BuildProviderPluginCache_Event) ProtoMessage() {}

func (x *BuildProviderPluginCache_Event) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[28]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use BuildProviderPluginCache_Event.ProtoReflect.Descriptor instead.
func (*BuildProviderPluginCache_Event) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{6, 1}
}

func (x *BuildProviderPluginCache_Event) GetEvent() isBuildProviderPluginCache_Event_Event {
	if x != nil {
		return x.Event
	}
	return nil
}

func (x *BuildProviderPluginCache_Event) GetPending() *BuildProviderPluginCache_Event_Pending {
	if x != nil {
		if x, ok := x.Event.(*BuildProviderPluginCache_Event_Pending_); ok {
			return x.Pending
		}
	}
	return nil
}

func (x *BuildProviderPluginCache_Event) GetAlreadyInstalled() *BuildProviderPluginCache_Event_ProviderVersion {
	if x != nil {
		if x, ok := x.Event.(*BuildProviderPluginCache_Event_AlreadyInstalled); ok {
			return x.AlreadyInstalled
		}
	}
	return nil
}

func (x *BuildProviderPluginCache_Event) GetBuiltIn() *BuildProviderPluginCache_Event_ProviderVersion {
	if x != nil {
		if x, ok := x.Event.(*BuildProviderPluginCache_Event_BuiltIn); ok {
			return x.BuiltIn
		}
	}
	return nil
}

func (x *BuildProviderPluginCache_Event) GetQueryBegin() *BuildProviderPluginCache_Event_ProviderConstraints {
	if x != nil {
		if x, ok := x.Event.(*BuildProviderPluginCache_Event_QueryBegin); ok {
			return x.QueryBegin
		}
	}
	return nil
}

func (x *BuildProviderPluginCache_Event) GetQuerySuccess() *BuildProviderPluginCache_Event_ProviderVersion {
	if x != nil {
		if x, ok := x.Event.(*BuildProviderPluginCache_Event_QuerySuccess); ok {
			return x.QuerySuccess
		}
	}
	return nil
}

func (x *BuildProviderPluginCache_Event) GetQueryWarnings() *BuildProviderPluginCache_Event_ProviderWarnings {
	if x != nil {
		if x, ok := x.Event.(*BuildProviderPluginCache_Event_QueryWarnings); ok {
			return x.QueryWarnings
		}
	}
	return nil
}

func (x *BuildProviderPluginCache_Event) GetFetchBegin() *BuildProviderPluginCache_Event_FetchBegin {
	if x != nil {
		if x, ok := x.Event.(*BuildProviderPluginCache_Event_FetchBegin_); ok {
			return x.FetchBegin
		}
	}
	return nil
}

func (x *BuildProviderPluginCache_Event) GetFetchComplete() *BuildProviderPluginCache_Event_FetchComplete {
	if x != nil {
		if x, ok := x.Event.(*BuildProviderPluginCache_Event_FetchComplete_); ok {
			return x.FetchComplete
		}
	}
	return nil
}

func (x *BuildProviderPluginCache_Event) GetDiagnostic() *terraform1.Diagnostic {
	if x != nil {
		if x, ok := x.Event.(*BuildProviderPluginCache_Event_Diagnostic); ok {
			return x.Diagnostic
		}
	}
	return nil
}

type isBuildProviderPluginCache_Event_Event interface {
	isBuildProviderPluginCache_Event_Event()
}

type BuildProviderPluginCache_Event_Pending_ struct {
	Pending *BuildProviderPluginCache_Event_Pending `protobuf:"bytes,1,opt,name=pending,proto3,oneof"`
}

type BuildProviderPluginCache_Event_AlreadyInstalled struct {
	AlreadyInstalled *BuildProviderPluginCache_Event_ProviderVersion `protobuf:"bytes,2,opt,name=already_installed,json=alreadyInstalled,proto3,oneof"`
}

type BuildProviderPluginCache_Event_BuiltIn struct {
	BuiltIn *BuildProviderPluginCache_Event_ProviderVersion `protobuf:"bytes,3,opt,name=built_in,json=builtIn,proto3,oneof"`
}

type BuildProviderPluginCache_Event_QueryBegin struct {
	QueryBegin *BuildProviderPluginCache_Event_ProviderConstraints `protobuf:"bytes,4,opt,name=query_begin,json=queryBegin,proto3,oneof"`
}

type BuildProviderPluginCache_Event_QuerySuccess struct {
	QuerySuccess *BuildProviderPluginCache_Event_ProviderVersion `protobuf:"bytes,5,opt,name=query_success,json=querySuccess,proto3,oneof"`
}

type BuildProviderPluginCache_Event_QueryWarnings struct {
	QueryWarnings *BuildProviderPluginCache_Event_ProviderWarnings `protobuf:"bytes,6,opt,name=query_warnings,json=queryWarnings,proto3,oneof"`
}

type BuildProviderPluginCache_Event_FetchBegin_ struct {
	FetchBegin *BuildProviderPluginCache_Event_FetchBegin `protobuf:"bytes,7,opt,name=fetch_begin,json=fetchBegin,proto3,oneof"`
}

type BuildProviderPluginCache_Event_FetchComplete_ struct {
	FetchComplete *BuildProviderPluginCache_Event_FetchComplete `protobuf:"bytes,8,opt,name=fetch_complete,json=fetchComplete,proto3,oneof"`
}

type BuildProviderPluginCache_Event_Diagnostic struct {
	Diagnostic *terraform1.Diagnostic `protobuf:"bytes,9,opt,name=diagnostic,proto3,oneof"`
}

func (*BuildProviderPluginCache_Event_Pending_) isBuildProviderPluginCache_Event_Event() {}

func (*BuildProviderPluginCache_Event_AlreadyInstalled) isBuildProviderPluginCache_Event_Event() {}

func (*BuildProviderPluginCache_Event_BuiltIn) isBuildProviderPluginCache_Event_Event() {}

func (*BuildProviderPluginCache_Event_QueryBegin) isBuildProviderPluginCache_Event_Event() {}

func (*BuildProviderPluginCache_Event_QuerySuccess) isBuildProviderPluginCache_Event_Event() {}

func (*BuildProviderPluginCache_Event_QueryWarnings) isBuildProviderPluginCache_Event_Event() {}

func (*BuildProviderPluginCache_Event_FetchBegin_) isBuildProviderPluginCache_Event_Event() {}

func (*BuildProviderPluginCache_Event_FetchComplete_) isBuildProviderPluginCache_Event_Event() {}

func (*BuildProviderPluginCache_Event_Diagnostic) isBuildProviderPluginCache_Event_Event() {}

type BuildProviderPluginCache_Request_InstallMethod struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Types that are valid to be assigned to Source:
	//
	//	*BuildProviderPluginCache_Request_InstallMethod_Direct
	//	*BuildProviderPluginCache_Request_InstallMethod_LocalMirrorDir
	//	*BuildProviderPluginCache_Request_InstallMethod_NetworkMirrorUrl
	Source        isBuildProviderPluginCache_Request_InstallMethod_Source `protobuf_oneof:"source"`
	Include       []string                                                `protobuf:"bytes,4,rep,name=include,proto3" json:"include,omitempty"`
	Exclude       []string                                                `protobuf:"bytes,5,rep,name=exclude,proto3" json:"exclude,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *BuildProviderPluginCache_Request_InstallMethod) Reset() {
	*x = BuildProviderPluginCache_Request_InstallMethod{}
	mi := &file_dependencies_proto_msgTypes[29]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *BuildProviderPluginCache_Request_InstallMethod) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*BuildProviderPluginCache_Request_InstallMethod) ProtoMessage() {}

func (x *BuildProviderPluginCache_Request_InstallMethod) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[29]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use BuildProviderPluginCache_Request_InstallMethod.ProtoReflect.Descriptor instead.
func (*BuildProviderPluginCache_Request_InstallMethod) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{6, 0, 0}
}

func (x *BuildProviderPluginCache_Request_InstallMethod) GetSource() isBuildProviderPluginCache_Request_InstallMethod_Source {
	if x != nil {
		return x.Source
	}
	return nil
}

func (x *BuildProviderPluginCache_Request_InstallMethod) GetDirect() bool {
	if x != nil {
		if x, ok := x.Source.(*BuildProviderPluginCache_Request_InstallMethod_Direct); ok {
			return x.Direct
		}
	}
	return false
}

func (x *BuildProviderPluginCache_Request_InstallMethod) GetLocalMirrorDir() string {
	if x != nil {
		if x, ok := x.Source.(*BuildProviderPluginCache_Request_InstallMethod_LocalMirrorDir); ok {
			return x.LocalMirrorDir
		}
	}
	return ""
}

func (x *BuildProviderPluginCache_Request_InstallMethod) GetNetworkMirrorUrl() string {
	if x != nil {
		if x, ok := x.Source.(*BuildProviderPluginCache_Request_InstallMethod_NetworkMirrorUrl); ok {
			return x.NetworkMirrorUrl
		}
	}
	return ""
}

func (x *BuildProviderPluginCache_Request_InstallMethod) GetInclude() []string {
	if x != nil {
		return x.Include
	}
	return nil
}

func (x *BuildProviderPluginCache_Request_InstallMethod) GetExclude() []string {
	if x != nil {
		return x.Exclude
	}
	return nil
}

type isBuildProviderPluginCache_Request_InstallMethod_Source interface {
	isBuildProviderPluginCache_Request_InstallMethod_Source()
}

type BuildProviderPluginCache_Request_InstallMethod_Direct struct {
	Direct bool `protobuf:"varint,1,opt,name=direct,proto3,oneof"`
}

type BuildProviderPluginCache_Request_InstallMethod_LocalMirrorDir struct {
	LocalMirrorDir string `protobuf:"bytes,2,opt,name=local_mirror_dir,json=localMirrorDir,proto3,oneof"`
}

type BuildProviderPluginCache_Request_InstallMethod_NetworkMirrorUrl struct {
	NetworkMirrorUrl string `protobuf:"bytes,3,opt,name=network_mirror_url,json=networkMirrorUrl,proto3,oneof"`
}

func (*BuildProviderPluginCache_Request_InstallMethod_Direct) isBuildProviderPluginCache_Request_InstallMethod_Source() {
}

func (*BuildProviderPluginCache_Request_InstallMethod_LocalMirrorDir) isBuildProviderPluginCache_Request_InstallMethod_Source() {
}

func (*BuildProviderPluginCache_Request_InstallMethod_NetworkMirrorUrl) isBuildProviderPluginCache_Request_InstallMethod_Source() {
}

type BuildProviderPluginCache_Event_Pending struct {
	state         protoimpl.MessageState                                `protogen:"open.v1"`
	Expected      []*BuildProviderPluginCache_Event_ProviderConstraints `protobuf:"bytes,1,rep,name=expected,proto3" json:"expected,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *BuildProviderPluginCache_Event_Pending) Reset() {
	*x = BuildProviderPluginCache_Event_Pending{}
	mi := &file_dependencies_proto_msgTypes[30]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *BuildProviderPluginCache_Event_Pending) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*BuildProviderPluginCache_Event_Pending) ProtoMessage() {}

func (x *BuildProviderPluginCache_Event_Pending) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[30]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use BuildProviderPluginCache_Event_Pending.ProtoReflect.Descriptor instead.
func (*BuildProviderPluginCache_Event_Pending) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{6, 1, 0}
}

func (x *BuildProviderPluginCache_Event_Pending) GetExpected() []*BuildProviderPluginCache_Event_ProviderConstraints {
	if x != nil {
		return x.Expected
	}
	return nil
}

type BuildProviderPluginCache_Event_ProviderConstraints struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	SourceAddr    string                 `protobuf:"bytes,1,opt,name=source_addr,json=sourceAddr,proto3" json:"source_addr,omitempty"`
	Versions      string                 `protobuf:"bytes,2,opt,name=versions,proto3" json:"versions,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *BuildProviderPluginCache_Event_ProviderConstraints) Reset() {
	*x = BuildProviderPluginCache_Event_ProviderConstraints{}
	mi := &file_dependencies_proto_msgTypes[31]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *BuildProviderPluginCache_Event_ProviderConstraints) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*BuildProviderPluginCache_Event_ProviderConstraints) ProtoMessage() {}

func (x *BuildProviderPluginCache_Event_ProviderConstraints) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[31]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use BuildProviderPluginCache_Event_ProviderConstraints.ProtoReflect.Descriptor instead.
func (*BuildProviderPluginCache_Event_ProviderConstraints) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{6, 1, 1}
}

func (x *BuildProviderPluginCache_Event_ProviderConstraints) GetSourceAddr() string {
	if x != nil {
		return x.SourceAddr
	}
	return ""
}

func (x *BuildProviderPluginCache_Event_ProviderConstraints) GetVersions() string {
	if x != nil {
		return x.Versions
	}
	return ""
}

type BuildProviderPluginCache_Event_ProviderVersion struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	SourceAddr    string                 `protobuf:"bytes,1,opt,name=source_addr,json=sourceAddr,proto3" json:"source_addr,omitempty"`
	Version       string                 `protobuf:"bytes,2,opt,name=version,proto3" json:"version,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *BuildProviderPluginCache_Event_ProviderVersion) Reset() {
	*x = BuildProviderPluginCache_Event_ProviderVersion{}
	mi := &file_dependencies_proto_msgTypes[32]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *BuildProviderPluginCache_Event_ProviderVersion) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*BuildProviderPluginCache_Event_ProviderVersion) ProtoMessage() {}

func (x *BuildProviderPluginCache_Event_ProviderVersion) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[32]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use BuildProviderPluginCache_Event_ProviderVersion.ProtoReflect.Descriptor instead.
func (*BuildProviderPluginCache_Event_ProviderVersion) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{6, 1, 2}
}

func (x *BuildProviderPluginCache_Event_ProviderVersion) GetSourceAddr() string {
	if x != nil {
		return x.SourceAddr
	}
	return ""
}

func (x *BuildProviderPluginCache_Event_ProviderVersion) GetVersion() string {
	if x != nil {
		return x.Version
	}
	return ""
}

type BuildProviderPluginCache_Event_ProviderWarnings struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	SourceAddr    string                 `protobuf:"bytes,1,opt,name=source_addr,json=sourceAddr,proto3" json:"source_addr,omitempty"`
	Warnings      []string               `protobuf:"bytes,2,rep,name=warnings,proto3" json:"warnings,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *BuildProviderPluginCache_Event_ProviderWarnings) Reset() {
	*x = BuildProviderPluginCache_Event_ProviderWarnings{}
	mi := &file_dependencies_proto_msgTypes[33]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *BuildProviderPluginCache_Event_ProviderWarnings) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*BuildProviderPluginCache_Event_ProviderWarnings) ProtoMessage() {}

func (x *BuildProviderPluginCache_Event_ProviderWarnings) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[33]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use BuildProviderPluginCache_Event_ProviderWarnings.ProtoReflect.Descriptor instead.
func (*BuildProviderPluginCache_Event_ProviderWarnings) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{6, 1, 3}
}

func (x *BuildProviderPluginCache_Event_ProviderWarnings) GetSourceAddr() string {
	if x != nil {
		return x.SourceAddr
	}
	return ""
}

func (x *BuildProviderPluginCache_Event_ProviderWarnings) GetWarnings() []string {
	if x != nil {
		return x.Warnings
	}
	return nil
}

type BuildProviderPluginCache_Event_FetchBegin struct {
	state           protoimpl.MessageState                          `protogen:"open.v1"`
	ProviderVersion *BuildProviderPluginCache_Event_ProviderVersion `protobuf:"bytes,1,opt,name=provider_version,json=providerVersion,proto3" json:"provider_version,omitempty"`
	Location        string                                          `protobuf:"bytes,2,opt,name=location,proto3" json:"location,omitempty"`
	unknownFields   protoimpl.UnknownFields
	sizeCache       protoimpl.SizeCache
}

func (x *BuildProviderPluginCache_Event_FetchBegin) Reset() {
	*x = BuildProviderPluginCache_Event_FetchBegin{}
	mi := &file_dependencies_proto_msgTypes[34]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *BuildProviderPluginCache_Event_FetchBegin) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*BuildProviderPluginCache_Event_FetchBegin) ProtoMessage() {}

func (x *BuildProviderPluginCache_Event_FetchBegin) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[34]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use BuildProviderPluginCache_Event_FetchBegin.ProtoReflect.Descriptor instead.
func (*BuildProviderPluginCache_Event_FetchBegin) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{6, 1, 4}
}

func (x *BuildProviderPluginCache_Event_FetchBegin) GetProviderVersion() *BuildProviderPluginCache_Event_ProviderVersion {
	if x != nil {
		return x.ProviderVersion
	}
	return nil
}

func (x *BuildProviderPluginCache_Event_FetchBegin) GetLocation() string {
	if x != nil {
		return x.Location
	}
	return ""
}

type BuildProviderPluginCache_Event_FetchComplete struct {
	state           protoimpl.MessageState                                  `protogen:"open.v1"`
	ProviderVersion *BuildProviderPluginCache_Event_ProviderVersion         `protobuf:"bytes,1,opt,name=provider_version,json=providerVersion,proto3" json:"provider_version,omitempty"`
	AuthResult      BuildProviderPluginCache_Event_FetchComplete_AuthResult `protobuf:"varint,2,opt,name=auth_result,json=authResult,proto3,enum=terraform1.dependencies.BuildProviderPluginCache_Event_FetchComplete_AuthResult" json:"auth_result,omitempty"`
	// If auth_result is one of the "_SIGNED" variants then this
	// might contain a UI-oriented identifier for the key that
	// signed the package. The exact format of this string is not
	// guaranteed; do not attempt to parse it or make automated
	// decisions based on it.
	KeyIdForDisplay string `protobuf:"bytes,3,opt,name=key_id_for_display,json=keyIdForDisplay,proto3" json:"key_id_for_display,omitempty"`
	unknownFields   protoimpl.UnknownFields
	sizeCache       protoimpl.SizeCache
}

func (x *BuildProviderPluginCache_Event_FetchComplete) Reset() {
	*x = BuildProviderPluginCache_Event_FetchComplete{}
	mi := &file_dependencies_proto_msgTypes[35]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *BuildProviderPluginCache_Event_FetchComplete) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*BuildProviderPluginCache_Event_FetchComplete) ProtoMessage() {}

func (x *BuildProviderPluginCache_Event_FetchComplete) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[35]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use BuildProviderPluginCache_Event_FetchComplete.ProtoReflect.Descriptor instead.
func (*BuildProviderPluginCache_Event_FetchComplete) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{6, 1, 5}
}

func (x *BuildProviderPluginCache_Event_FetchComplete) GetProviderVersion() *BuildProviderPluginCache_Event_ProviderVersion {
	if x != nil {
		return x.ProviderVersion
	}
	return nil
}

func (x *BuildProviderPluginCache_Event_FetchComplete) GetAuthResult() BuildProviderPluginCache_Event_FetchComplete_AuthResult {
	if x != nil {
		return x.AuthResult
	}
	return BuildProviderPluginCache_Event_FetchComplete_UNKNOWN
}

func (x *BuildProviderPluginCache_Event_FetchComplete) GetKeyIdForDisplay() string {
	if x != nil {
		return x.KeyIdForDisplay
	}
	return ""
}

type OpenProviderPluginCache_Request struct {
	state    protoimpl.MessageState `protogen:"open.v1"`
	CacheDir string                 `protobuf:"bytes,1,opt,name=cache_dir,json=cacheDir,proto3" json:"cache_dir,omitempty"`
	// As with the field of the same name in BuildProviderPluginCache.Request.
	//
	// If this is set to anything other than this RPC server's native
	// platform then any operations that require executing the provider
	// plugin are likely to fail due to executable format errors or
	// similar. However, it's valid to use the returned handle with
	// GetCachedProviders, since it only analyzes the cache metadata
	// and doesn't actually run the plugins inside.
	OverridePlatform string `protobuf:"bytes,2,opt,name=override_platform,json=overridePlatform,proto3" json:"override_platform,omitempty"`
	unknownFields    protoimpl.UnknownFields
	sizeCache        protoimpl.SizeCache
}

func (x *OpenProviderPluginCache_Request) Reset() {
	*x = OpenProviderPluginCache_Request{}
	mi := &file_dependencies_proto_msgTypes[36]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *OpenProviderPluginCache_Request) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*OpenProviderPluginCache_Request) ProtoMessage() {}

func (x *OpenProviderPluginCache_Request) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[36]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use OpenProviderPluginCache_Request.ProtoReflect.Descriptor instead.
func (*OpenProviderPluginCache_Request) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{7, 0}
}

func (x *OpenProviderPluginCache_Request) GetCacheDir() string {
	if x != nil {
		return x.CacheDir
	}
	return ""
}

func (x *OpenProviderPluginCache_Request) GetOverridePlatform() string {
	if x != nil {
		return x.OverridePlatform
	}
	return ""
}

type OpenProviderPluginCache_Response struct {
	state               protoimpl.MessageState `protogen:"open.v1"`
	ProviderCacheHandle int64                  `protobuf:"varint,1,opt,name=provider_cache_handle,json=providerCacheHandle,proto3" json:"provider_cache_handle,omitempty"`
	unknownFields       protoimpl.UnknownFields
	sizeCache           protoimpl.SizeCache
}

func (x *OpenProviderPluginCache_Response) Reset() {
	*x = OpenProviderPluginCache_Response{}
	mi := &file_dependencies_proto_msgTypes[37]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *OpenProviderPluginCache_Response) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*OpenProviderPluginCache_Response) ProtoMessage() {}

func (x *OpenProviderPluginCache_Response) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[37]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use OpenProviderPluginCache_Response.ProtoReflect.Descriptor instead.
func (*OpenProviderPluginCache_Response) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{7, 1}
}

func (x *OpenProviderPluginCache_Response) GetProviderCacheHandle() int64 {
	if x != nil {
		return x.ProviderCacheHandle
	}
	return 0
}

type CloseProviderPluginCache_Request struct {
	state               protoimpl.MessageState `protogen:"open.v1"`
	ProviderCacheHandle int64                  `protobuf:"varint,1,opt,name=provider_cache_handle,json=providerCacheHandle,proto3" json:"provider_cache_handle,omitempty"`
	unknownFields       protoimpl.UnknownFields
	sizeCache           protoimpl.SizeCache
}

func (x *CloseProviderPluginCache_Request) Reset() {
	*x = CloseProviderPluginCache_Request{}
	mi := &file_dependencies_proto_msgTypes[38]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *CloseProviderPluginCache_Request) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*CloseProviderPluginCache_Request) ProtoMessage() {}

func (x *CloseProviderPluginCache_Request) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[38]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use CloseProviderPluginCache_Request.ProtoReflect.Descriptor instead.
func (*CloseProviderPluginCache_Request) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{8, 0}
}

func (x *CloseProviderPluginCache_Request) GetProviderCacheHandle() int64 {
	if x != nil {
		return x.ProviderCacheHandle
	}
	return 0
}

type CloseProviderPluginCache_Response struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *CloseProviderPluginCache_Response) Reset() {
	*x = CloseProviderPluginCache_Response{}
	mi := &file_dependencies_proto_msgTypes[39]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *CloseProviderPluginCache_Response) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*CloseProviderPluginCache_Response) ProtoMessage() {}

func (x *CloseProviderPluginCache_Response) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[39]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use CloseProviderPluginCache_Response.ProtoReflect.Descriptor instead.
func (*CloseProviderPluginCache_Response) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{8, 1}
}

type GetCachedProviders_Request struct {
	state               protoimpl.MessageState `protogen:"open.v1"`
	ProviderCacheHandle int64                  `protobuf:"varint,1,opt,name=provider_cache_handle,json=providerCacheHandle,proto3" json:"provider_cache_handle,omitempty"`
	unknownFields       protoimpl.UnknownFields
	sizeCache           protoimpl.SizeCache
}

func (x *GetCachedProviders_Request) Reset() {
	*x = GetCachedProviders_Request{}
	mi := &file_dependencies_proto_msgTypes[40]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetCachedProviders_Request) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetCachedProviders_Request) ProtoMessage() {}

func (x *GetCachedProviders_Request) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[40]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetCachedProviders_Request.ProtoReflect.Descriptor instead.
func (*GetCachedProviders_Request) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{9, 0}
}

func (x *GetCachedProviders_Request) GetProviderCacheHandle() int64 {
	if x != nil {
		return x.ProviderCacheHandle
	}
	return 0
}

type GetCachedProviders_Response struct {
	state              protoimpl.MessageState        `protogen:"open.v1"`
	AvailableProviders []*terraform1.ProviderPackage `protobuf:"bytes,1,rep,name=available_providers,json=availableProviders,proto3" json:"available_providers,omitempty"`
	unknownFields      protoimpl.UnknownFields
	sizeCache          protoimpl.SizeCache
}

func (x *GetCachedProviders_Response) Reset() {
	*x = GetCachedProviders_Response{}
	mi := &file_dependencies_proto_msgTypes[41]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetCachedProviders_Response) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetCachedProviders_Response) ProtoMessage() {}

func (x *GetCachedProviders_Response) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[41]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetCachedProviders_Response.ProtoReflect.Descriptor instead.
func (*GetCachedProviders_Response) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{9, 1}
}

func (x *GetCachedProviders_Response) GetAvailableProviders() []*terraform1.ProviderPackage {
	if x != nil {
		return x.AvailableProviders
	}
	return nil
}

type GetBuiltInProviders_Request struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetBuiltInProviders_Request) Reset() {
	*x = GetBuiltInProviders_Request{}
	mi := &file_dependencies_proto_msgTypes[42]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetBuiltInProviders_Request) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetBuiltInProviders_Request) ProtoMessage() {}

func (x *GetBuiltInProviders_Request) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[42]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetBuiltInProviders_Request.ProtoReflect.Descriptor instead.
func (*GetBuiltInProviders_Request) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{10, 0}
}

type GetBuiltInProviders_Response struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// The built-in providers that are compiled in to this Terraform Core
	// server.
	//
	// This uses terraform1.ProviderPackage messages for consistency with the other
	// operations which list providers, but built-in providers do not
	// have version numbers nor hashes so those fields will always be
	// unset in the result.
	AvailableProviders []*terraform1.ProviderPackage `protobuf:"bytes,1,rep,name=available_providers,json=availableProviders,proto3" json:"available_providers,omitempty"`
	unknownFields      protoimpl.UnknownFields
	sizeCache          protoimpl.SizeCache
}

func (x *GetBuiltInProviders_Response) Reset() {
	*x = GetBuiltInProviders_Response{}
	mi := &file_dependencies_proto_msgTypes[43]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetBuiltInProviders_Response) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetBuiltInProviders_Response) ProtoMessage() {}

func (x *GetBuiltInProviders_Response) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[43]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetBuiltInProviders_Response.ProtoReflect.Descriptor instead.
func (*GetBuiltInProviders_Response) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{10, 1}
}

func (x *GetBuiltInProviders_Response) GetAvailableProviders() []*terraform1.ProviderPackage {
	if x != nil {
		return x.AvailableProviders
	}
	return nil
}

type GetProviderSchema_Request struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// The address of the provider to retrieve schema for, using the
	// typical provider source address syntax.
	//
	// When requesting schema based on a terraform1.ProviderPackage message, populate
	// this with its "source_addr" field.
	ProviderAddr string `protobuf:"bytes,1,opt,name=provider_addr,json=providerAddr,proto3" json:"provider_addr,omitempty"`
	// The version number of the given provider to retrieve the schema
	// of, which must have already been populated into the cache directory.
	//
	// Not supported for built-in providers because we can only access the
	// single "version" of the provider that's compiled into this Terraform
	// Core server, and so must be left unset or empty for those.
	//
	// When requesting schema based on a terraform1.ProviderPackage message, populate
	// this with its "version" field.
	ProviderVersion string `protobuf:"bytes,2,opt,name=provider_version,json=providerVersion,proto3" json:"provider_version,omitempty"`
	// The handle for the previously-opened provider plugin cache to
	// load the provider plugin from.
	//
	// Optional for built-in providers, but can still be specified in that
	// case if desired so that callers can safely just send the handle they
	// have in all cases and be naive about which providers are and are
	// not built in.
	ProviderCacheHandle int64 `protobuf:"varint,3,opt,name=provider_cache_handle,json=providerCacheHandle,proto3" json:"provider_cache_handle,omitempty"`
	unknownFields       protoimpl.UnknownFields
	sizeCache           protoimpl.SizeCache
}

func (x *GetProviderSchema_Request) Reset() {
	*x = GetProviderSchema_Request{}
	mi := &file_dependencies_proto_msgTypes[44]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetProviderSchema_Request) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetProviderSchema_Request) ProtoMessage() {}

func (x *GetProviderSchema_Request) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[44]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetProviderSchema_Request.ProtoReflect.Descriptor instead.
func (*GetProviderSchema_Request) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{11, 0}
}

func (x *GetProviderSchema_Request) GetProviderAddr() string {
	if x != nil {
		return x.ProviderAddr
	}
	return ""
}

func (x *GetProviderSchema_Request) GetProviderVersion() string {
	if x != nil {
		return x.ProviderVersion
	}
	return ""
}

func (x *GetProviderSchema_Request) GetProviderCacheHandle() int64 {
	if x != nil {
		return x.ProviderCacheHandle
	}
	return 0
}

type GetProviderSchema_Response struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Schema        *ProviderSchema        `protobuf:"bytes,1,opt,name=schema,proto3" json:"schema,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetProviderSchema_Response) Reset() {
	*x = GetProviderSchema_Response{}
	mi := &file_dependencies_proto_msgTypes[45]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetProviderSchema_Response) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetProviderSchema_Response) ProtoMessage() {}

func (x *GetProviderSchema_Response) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[45]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetProviderSchema_Response.ProtoReflect.Descriptor instead.
func (*GetProviderSchema_Response) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{11, 1}
}

func (x *GetProviderSchema_Response) GetSchema() *ProviderSchema {
	if x != nil {
		return x.Schema
	}
	return nil
}

type Schema_Block struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Attributes    []*Schema_Attribute    `protobuf:"bytes,1,rep,name=attributes,proto3" json:"attributes,omitempty"`
	BlockTypes    []*Schema_NestedBlock  `protobuf:"bytes,2,rep,name=block_types,json=blockTypes,proto3" json:"block_types,omitempty"`
	Description   *Schema_DocString      `protobuf:"bytes,3,opt,name=description,proto3" json:"description,omitempty"`
	Deprecated    bool                   `protobuf:"varint,4,opt,name=deprecated,proto3" json:"deprecated,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *Schema_Block) Reset() {
	*x = Schema_Block{}
	mi := &file_dependencies_proto_msgTypes[49]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *Schema_Block) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*Schema_Block) ProtoMessage() {}

func (x *Schema_Block) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[49]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use Schema_Block.ProtoReflect.Descriptor instead.
func (*Schema_Block) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{14, 0}
}

func (x *Schema_Block) GetAttributes() []*Schema_Attribute {
	if x != nil {
		return x.Attributes
	}
	return nil
}

func (x *Schema_Block) GetBlockTypes() []*Schema_NestedBlock {
	if x != nil {
		return x.BlockTypes
	}
	return nil
}

func (x *Schema_Block) GetDescription() *Schema_DocString {
	if x != nil {
		return x.Description
	}
	return nil
}

func (x *Schema_Block) GetDeprecated() bool {
	if x != nil {
		return x.Deprecated
	}
	return false
}

type Schema_Attribute struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Name          string                 `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	Type          []byte                 `protobuf:"bytes,2,opt,name=type,proto3" json:"type,omitempty"`
	NestedType    *Schema_Object         `protobuf:"bytes,10,opt,name=nested_type,json=nestedType,proto3" json:"nested_type,omitempty"`
	Description   *Schema_DocString      `protobuf:"bytes,3,opt,name=description,proto3" json:"description,omitempty"`
	Required      bool                   `protobuf:"varint,4,opt,name=required,proto3" json:"required,omitempty"`
	Optional      bool                   `protobuf:"varint,5,opt,name=optional,proto3" json:"optional,omitempty"`
	Computed      bool                   `protobuf:"varint,6,opt,name=computed,proto3" json:"computed,omitempty"`
	Sensitive     bool                   `protobuf:"varint,7,opt,name=sensitive,proto3" json:"sensitive,omitempty"`
	Deprecated    bool                   `protobuf:"varint,8,opt,name=deprecated,proto3" json:"deprecated,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *Schema_Attribute) Reset() {
	*x = Schema_Attribute{}
	mi := &file_dependencies_proto_msgTypes[50]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *Schema_Attribute) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*Schema_Attribute) ProtoMessage() {}

func (x *Schema_Attribute) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[50]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use Schema_Attribute.ProtoReflect.Descriptor instead.
func (*Schema_Attribute) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{14, 1}
}

func (x *Schema_Attribute) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

func (x *Schema_Attribute) GetType() []byte {
	if x != nil {
		return x.Type
	}
	return nil
}

func (x *Schema_Attribute) GetNestedType() *Schema_Object {
	if x != nil {
		return x.NestedType
	}
	return nil
}

func (x *Schema_Attribute) GetDescription() *Schema_DocString {
	if x != nil {
		return x.Description
	}
	return nil
}

func (x *Schema_Attribute) GetRequired() bool {
	if x != nil {
		return x.Required
	}
	return false
}

func (x *Schema_Attribute) GetOptional() bool {
	if x != nil {
		return x.Optional
	}
	return false
}

func (x *Schema_Attribute) GetComputed() bool {
	if x != nil {
		return x.Computed
	}
	return false
}

func (x *Schema_Attribute) GetSensitive() bool {
	if x != nil {
		return x.Sensitive
	}
	return false
}

func (x *Schema_Attribute) GetDeprecated() bool {
	if x != nil {
		return x.Deprecated
	}
	return false
}

type Schema_NestedBlock struct {
	state         protoimpl.MessageState         `protogen:"open.v1"`
	TypeName      string                         `protobuf:"bytes,1,opt,name=type_name,json=typeName,proto3" json:"type_name,omitempty"`
	Block         *Schema_Block                  `protobuf:"bytes,2,opt,name=block,proto3" json:"block,omitempty"`
	Nesting       Schema_NestedBlock_NestingMode `protobuf:"varint,3,opt,name=nesting,proto3,enum=terraform1.dependencies.Schema_NestedBlock_NestingMode" json:"nesting,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *Schema_NestedBlock) Reset() {
	*x = Schema_NestedBlock{}
	mi := &file_dependencies_proto_msgTypes[51]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *Schema_NestedBlock) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*Schema_NestedBlock) ProtoMessage() {}

func (x *Schema_NestedBlock) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[51]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use Schema_NestedBlock.ProtoReflect.Descriptor instead.
func (*Schema_NestedBlock) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{14, 2}
}

func (x *Schema_NestedBlock) GetTypeName() string {
	if x != nil {
		return x.TypeName
	}
	return ""
}

func (x *Schema_NestedBlock) GetBlock() *Schema_Block {
	if x != nil {
		return x.Block
	}
	return nil
}

func (x *Schema_NestedBlock) GetNesting() Schema_NestedBlock_NestingMode {
	if x != nil {
		return x.Nesting
	}
	return Schema_NestedBlock_INVALID
}

type Schema_Object struct {
	state         protoimpl.MessageState    `protogen:"open.v1"`
	Attributes    []*Schema_Attribute       `protobuf:"bytes,1,rep,name=attributes,proto3" json:"attributes,omitempty"`
	Nesting       Schema_Object_NestingMode `protobuf:"varint,3,opt,name=nesting,proto3,enum=terraform1.dependencies.Schema_Object_NestingMode" json:"nesting,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *Schema_Object) Reset() {
	*x = Schema_Object{}
	mi := &file_dependencies_proto_msgTypes[52]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *Schema_Object) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*Schema_Object) ProtoMessage() {}

func (x *Schema_Object) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[52]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use Schema_Object.ProtoReflect.Descriptor instead.
func (*Schema_Object) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{14, 3}
}

func (x *Schema_Object) GetAttributes() []*Schema_Attribute {
	if x != nil {
		return x.Attributes
	}
	return nil
}

func (x *Schema_Object) GetNesting() Schema_Object_NestingMode {
	if x != nil {
		return x.Nesting
	}
	return Schema_Object_INVALID
}

type Schema_DocString struct {
	state         protoimpl.MessageState  `protogen:"open.v1"`
	Description   string                  `protobuf:"bytes,1,opt,name=description,proto3" json:"description,omitempty"`
	Format        Schema_DocString_Format `protobuf:"varint,2,opt,name=format,proto3,enum=terraform1.dependencies.Schema_DocString_Format" json:"format,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *Schema_DocString) Reset() {
	*x = Schema_DocString{}
	mi := &file_dependencies_proto_msgTypes[53]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *Schema_DocString) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*Schema_DocString) ProtoMessage() {}

func (x *Schema_DocString) ProtoReflect() protoreflect.Message {
	mi := &file_dependencies_proto_msgTypes[53]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use Schema_DocString.ProtoReflect.Descriptor instead.
func (*Schema_DocString) Descriptor() ([]byte, []int) {
	return file_dependencies_proto_rawDescGZIP(), []int{14, 4}
}

func (x *Schema_DocString) GetDescription() string {
	if x != nil {
		return x.Description
	}
	return ""
}

func (x *Schema_DocString) GetFormat() Schema_DocString_Format {
	if x != nil {
		return x.Format
	}
	return Schema_DocString_PLAIN
}

var File_dependencies_proto protoreflect.FileDescriptor

const file_dependencies_proto_rawDesc = "" +
	"\n" +
	"\x12dependencies.proto\x12\x17terraform1.dependencies\x1a\x10terraform1.proto\"z\n" +
	"\x10OpenSourceBundle\x1a(\n" +
	"\aRequest\x12\x1d\n" +
	"\n" +
	"local_path\x18\x01 \x01(\tR\tlocalPath\x1a<\n" +
	"\bResponse\x120\n" +
	"\x14source_bundle_handle\x18\x01 \x01(\x03R\x12sourceBundleHandle\"\\\n" +
	"\x11CloseSourceBundle\x1a;\n" +
	"\aRequest\x120\n" +
	"\x14source_bundle_handle\x18\x01 \x01(\x03R\x12sourceBundleHandle\x1a\n" +
	"\n" +
	"\bResponse\"\x95\x02\n" +
	"\x16OpenDependencyLockFile\x1a}\n" +
	"\aRequest\x120\n" +
	"\x14source_bundle_handle\x18\x01 \x01(\x03R\x12sourceBundleHandle\x12@\n" +
	"\x0esource_address\x18\x02 \x01(\v2\x19.terraform1.SourceAddressR\rsourceAddress\x1a|\n" +
	"\bResponse\x126\n" +
	"\x17dependency_locks_handle\x18\x01 \x01(\x03R\x15dependencyLocksHandle\x128\n" +
	"\vdiagnostics\x18\x02 \x03(\v2\x16.terraform1.DiagnosticR\vdiagnostics\"\xb4\x01\n" +
	"\x15CreateDependencyLocks\x1aW\n" +
	"\aRequest\x12L\n" +
	"\x13provider_selections\x18\x01 \x03(\v2\x1b.terraform1.ProviderPackageR\x12providerSelections\x1aB\n" +
	"\bResponse\x126\n" +
	"\x17dependency_locks_handle\x18\x01 \x01(\x03R\x15dependencyLocksHandle\"e\n" +
	"\x14CloseDependencyLocks\x1aA\n" +
	"\aRequest\x126\n" +
	"\x17dependency_locks_handle\x18\x01 \x01(\x03R\x15dependencyLocksHandle\x1a\n" +
	"\n" +
	"\bResponse\"\xba\x01\n" +
	"\x1dGetLockedProviderDependencies\x1aA\n" +
	"\aRequest\x126\n" +
	"\x17dependency_locks_handle\x18\x01 \x01(\x03R\x15dependencyLocksHandle\x1aV\n" +
	"\bResponse\x12J\n" +
	"\x12selected_providers\x18\x01 \x03(\v2\x1b.terraform1.ProviderPackageR\x11selectedProviders\"\xb4\x12\n" +
	"\x18BuildProviderPluginCache\x1a\xcd\x03\n" +
	"\aRequest\x12\x1b\n" +
	"\tcache_dir\x18\x01 \x01(\tR\bcacheDir\x126\n" +
	"\x17dependency_locks_handle\x18\x02 \x01(\x03R\x15dependencyLocksHandle\x12z\n" +
	"\x14installation_methods\x18\x03 \x03(\v2G.terraform1.dependencies.BuildProviderPluginCache.Request.InstallMethodR\x13installationMethods\x12+\n" +
	"\x11override_platform\x18\x04 \x01(\tR\x10overridePlatform\x1a\xc3\x01\n" +
	"\rInstallMethod\x12\x18\n" +
	"\x06direct\x18\x01 \x01(\bH\x00R\x06direct\x12*\n" +
	"\x10local_mirror_dir\x18\x02 \x01(\tH\x00R\x0elocalMirrorDir\x12.\n" +
	"\x12network_mirror_url\x18\x03 \x01(\tH\x00R\x10networkMirrorUrl\x12\x18\n" +
	"\ainclude\x18\x04 \x03(\tR\ainclude\x12\x18\n" +
	"\aexclude\x18\x05 \x03(\tR\aexcludeB\b\n" +
	"\x06source\x1a\xc7\x0e\n" +
	"\x05Event\x12[\n" +
	"\apending\x18\x01 \x01(\v2?.terraform1.dependencies.BuildProviderPluginCache.Event.PendingH\x00R\apending\x12v\n" +
	"\x11already_installed\x18\x02 \x01(\v2G.terraform1.dependencies.BuildProviderPluginCache.Event.ProviderVersionH\x00R\x10alreadyInstalled\x12d\n" +
	"\bbuilt_in\x18\x03 \x01(\v2G.terraform1.dependencies.BuildProviderPluginCache.Event.ProviderVersionH\x00R\abuiltIn\x12n\n" +
	"\vquery_begin\x18\x04 \x01(\v2K.terraform1.dependencies.BuildProviderPluginCache.Event.ProviderConstraintsH\x00R\n" +
	"queryBegin\x12n\n" +
	"\rquery_success\x18\x05 \x01(\v2G.terraform1.dependencies.BuildProviderPluginCache.Event.ProviderVersionH\x00R\fquerySuccess\x12q\n" +
	"\x0equery_warnings\x18\x06 \x01(\v2H.terraform1.dependencies.BuildProviderPluginCache.Event.ProviderWarningsH\x00R\rqueryWarnings\x12e\n" +
	"\vfetch_begin\x18\a \x01(\v2B.terraform1.dependencies.BuildProviderPluginCache.Event.FetchBeginH\x00R\n" +
	"fetchBegin\x12n\n" +
	"\x0efetch_complete\x18\b \x01(\v2E.terraform1.dependencies.BuildProviderPluginCache.Event.FetchCompleteH\x00R\rfetchComplete\x128\n" +
	"\n" +
	"diagnostic\x18\t \x01(\v2\x16.terraform1.DiagnosticH\x00R\n" +
	"diagnostic\x1ar\n" +
	"\aPending\x12g\n" +
	"\bexpected\x18\x01 \x03(\v2K.terraform1.dependencies.BuildProviderPluginCache.Event.ProviderConstraintsR\bexpected\x1aR\n" +
	"\x13ProviderConstraints\x12\x1f\n" +
	"\vsource_addr\x18\x01 \x01(\tR\n" +
	"sourceAddr\x12\x1a\n" +
	"\bversions\x18\x02 \x01(\tR\bversions\x1aL\n" +
	"\x0fProviderVersion\x12\x1f\n" +
	"\vsource_addr\x18\x01 \x01(\tR\n" +
	"sourceAddr\x12\x18\n" +
	"\aversion\x18\x02 \x01(\tR\aversion\x1aO\n" +
	"\x10ProviderWarnings\x12\x1f\n" +
	"\vsource_addr\x18\x01 \x01(\tR\n" +
	"sourceAddr\x12\x1a\n" +
	"\bwarnings\x18\x02 \x03(\tR\bwarnings\x1a\x9c\x01\n" +
	"\n" +
	"FetchBegin\x12r\n" +
	"\x10provider_version\x18\x01 \x01(\v2G.terraform1.dependencies.BuildProviderPluginCache.Event.ProviderVersionR\x0fproviderVersion\x12\x1a\n" +
	"\blocation\x18\x02 \x01(\tR\blocation\x1a\x8f\x03\n" +
	"\rFetchComplete\x12r\n" +
	"\x10provider_version\x18\x01 \x01(\v2G.terraform1.dependencies.BuildProviderPluginCache.Event.ProviderVersionR\x0fproviderVersion\x12q\n" +
	"\vauth_result\x18\x02 \x01(\x0e2P.terraform1.dependencies.BuildProviderPluginCache.Event.FetchComplete.AuthResultR\n" +
	"authResult\x12+\n" +
	"\x12key_id_for_display\x18\x03 \x01(\tR\x0fkeyIdForDisplay\"j\n" +
	"\n" +
	"AuthResult\x12\v\n" +
	"\aUNKNOWN\x10\x00\x12\x15\n" +
	"\x11VERIFIED_CHECKSUM\x10\x01\x12\x13\n" +
	"\x0fOFFICIAL_SIGNED\x10\x02\x12\x12\n" +
	"\x0ePARTNER_SIGNED\x10\x03\x12\x0f\n" +
	"\vSELF_SIGNED\x10\x04B\a\n" +
	"\x05event\"\xae\x01\n" +
	"\x17OpenProviderPluginCache\x1aS\n" +
	"\aRequest\x12\x1b\n" +
	"\tcache_dir\x18\x01 \x01(\tR\bcacheDir\x12+\n" +
	"\x11override_platform\x18\x02 \x01(\tR\x10overridePlatform\x1a>\n" +
	"\bResponse\x122\n" +
	"\x15provider_cache_handle\x18\x01 \x01(\x03R\x13providerCacheHandle\"e\n" +
	"\x18CloseProviderPluginCache\x1a=\n" +
	"\aRequest\x122\n" +
	"\x15provider_cache_handle\x18\x01 \x01(\x03R\x13providerCacheHandle\x1a\n" +
	"\n" +
	"\bResponse\"\xad\x01\n" +
	"\x12GetCachedProviders\x1a=\n" +
	"\aRequest\x122\n" +
	"\x15provider_cache_handle\x18\x01 \x01(\x03R\x13providerCacheHandle\x1aX\n" +
	"\bResponse\x12L\n" +
	"\x13available_providers\x18\x01 \x03(\v2\x1b.terraform1.ProviderPackageR\x12availableProviders\"z\n" +
	"\x13GetBuiltInProviders\x1a\t\n" +
	"\aRequest\x1aX\n" +
	"\bResponse\x12L\n" +
	"\x13available_providers\x18\x01 \x03(\v2\x1b.terraform1.ProviderPackageR\x12availableProviders\"\xf0\x01\n" +
	"\x11GetProviderSchema\x1a\x8d\x01\n" +
	"\aRequest\x12#\n" +
	"\rprovider_addr\x18\x01 \x01(\tR\fproviderAddr\x12)\n" +
	"\x10provider_version\x18\x02 \x01(\tR\x0fproviderVersion\x122\n" +
	"\x15provider_cache_handle\x18\x03 \x01(\x03R\x13providerCacheHandle\x1aK\n" +
	"\bResponse\x12?\n" +
	"\x06schema\x18\x01 \x01(\v2'.terraform1.dependencies.ProviderSchemaR\x06schema\"\xd8\x05\n" +
	"\x0eProviderSchema\x12H\n" +
	"\x0fprovider_config\x18\x01 \x01(\v2\x1f.terraform1.dependencies.SchemaR\x0eproviderConfig\x12w\n" +
	"\x16managed_resource_types\x18\x02 \x03(\v2A.terraform1.dependencies.ProviderSchema.ManagedResourceTypesEntryR\x14managedResourceTypes\x12n\n" +
	"\x13data_resource_types\x18\x03 \x03(\v2>.terraform1.dependencies.ProviderSchema.DataResourceTypesEntryR\x11dataResourceTypes\x12[\n" +
	"\faction_types\x18\x04 \x03(\v28.terraform1.dependencies.ProviderSchema.ActionTypesEntryR\vactionTypes\x1ah\n" +
	"\x19ManagedResourceTypesEntry\x12\x10\n" +
	"\x03key\x18\x01 \x01(\tR\x03key\x125\n" +
	"\x05value\x18\x02 \x01(\v2\x1f.terraform1.dependencies.SchemaR\x05value:\x028\x01\x1ae\n" +
	"\x16DataResourceTypesEntry\x12\x10\n" +
	"\x03key\x18\x01 \x01(\tR\x03key\x125\n" +
	"\x05value\x18\x02 \x01(\v2\x1f.terraform1.dependencies.SchemaR\x05value:\x028\x01\x1ae\n" +
	"\x10ActionTypesEntry\x12\x10\n" +
	"\x03key\x18\x01 \x01(\tR\x03key\x12;\n" +
	"\x05value\x18\x02 \x01(\v2%.terraform1.dependencies.ActionSchemaR\x05value:\x028\x01\"G\n" +
	"\fActionSchema\x127\n" +
	"\x06schema\x18\x01 \x01(\v2\x1f.terraform1.dependencies.SchemaR\x06schema\"\xc4\n" +
	"\n" +
	"\x06Schema\x12;\n" +
	"\x05block\x18\x01 \x01(\v2%.terraform1.dependencies.Schema.BlockR\x05block\x1a\x8d\x02\n" +
	"\x05Block\x12I\n" +
	"\n" +
	"attributes\x18\x01 \x03(\v2).terraform1.dependencies.Schema.AttributeR\n" +
	"attributes\x12L\n" +
	"\vblock_types\x18\x02 \x03(\v2+.terraform1.dependencies.Schema.NestedBlockR\n" +
	"blockTypes\x12K\n" +
	"\vdescription\x18\x03 \x01(\v2).terraform1.dependencies.Schema.DocStringR\vdescription\x12\x1e\n" +
	"\n" +
	"deprecated\x18\x04 \x01(\bR\n" +
	"deprecated\x1a\xdb\x02\n" +
	"\tAttribute\x12\x12\n" +
	"\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n" +
	"\x04type\x18\x02 \x01(\fR\x04type\x12G\n" +
	"\vnested_type\x18\n" +
	" \x01(\v2&.terraform1.dependencies.Schema.ObjectR\n" +
	"nestedType\x12K\n" +
	"\vdescription\x18\x03 \x01(\v2).terraform1.dependencies.Schema.DocStringR\vdescription\x12\x1a\n" +
	"\brequired\x18\x04 \x01(\bR\brequired\x12\x1a\n" +
	"\boptional\x18\x05 \x01(\bR\boptional\x12\x1a\n" +
	"\bcomputed\x18\x06 \x01(\bR\bcomputed\x12\x1c\n" +
	"\tsensitive\x18\a \x01(\bR\tsensitive\x12\x1e\n" +
	"\n" +
	"deprecated\x18\b \x01(\bR\n" +
	"deprecated\x1a\x89\x02\n" +
	"\vNestedBlock\x12\x1b\n" +
	"\ttype_name\x18\x01 \x01(\tR\btypeName\x12;\n" +
	"\x05block\x18\x02 \x01(\v2%.terraform1.dependencies.Schema.BlockR\x05block\x12Q\n" +
	"\anesting\x18\x03 \x01(\x0e27.terraform1.dependencies.Schema.NestedBlock.NestingModeR\anesting\"M\n" +
	"\vNestingMode\x12\v\n" +
	"\aINVALID\x10\x00\x12\n" +
	"\n" +
	"\x06SINGLE\x10\x01\x12\b\n" +
	"\x04LIST\x10\x02\x12\a\n" +
	"\x03SET\x10\x03\x12\a\n" +
	"\x03MAP\x10\x04\x12\t\n" +
	"\x05GROUP\x10\x05\x1a\xe5\x01\n" +
	"\x06Object\x12I\n" +
	"\n" +
	"attributes\x18\x01 \x03(\v2).terraform1.dependencies.Schema.AttributeR\n" +
	"attributes\x12L\n" +
	"\anesting\x18\x03 \x01(\x0e22.terraform1.dependencies.Schema.Object.NestingModeR\anesting\"B\n" +
	"\vNestingMode\x12\v\n" +
	"\aINVALID\x10\x00\x12\n" +
	"\n" +
	"\x06SINGLE\x10\x01\x12\b\n" +
	"\x04LIST\x10\x02\x12\a\n" +
	"\x03SET\x10\x03\x12\a\n" +
	"\x03MAP\x10\x04\x1a\x9a\x01\n" +
	"\tDocString\x12 \n" +
	"\vdescription\x18\x01 \x01(\tR\vdescription\x12H\n" +
	"\x06format\x18\x02 \x01(\x0e20.terraform1.dependencies.Schema.DocString.FormatR\x06format\"!\n" +
	"\x06Format\x12\t\n" +
	"\x05PLAIN\x10\x00\x12\f\n" +
	"\bMARKDOWN\x10\x012\x87\r\n" +
	"\fDependencies\x12y\n" +
	"\x10OpenSourceBundle\x121.terraform1.dependencies.OpenSourceBundle.Request\x1a2.terraform1.dependencies.OpenSourceBundle.Response\x12|\n" +
	"\x11CloseSourceBundle\x122.terraform1.dependencies.CloseSourceBundle.Request\x1a3.terraform1.dependencies.CloseSourceBundle.Response\x12\x8b\x01\n" +
	"\x16OpenDependencyLockFile\x127.terraform1.dependencies.OpenDependencyLockFile.Request\x1a8.terraform1.dependencies.OpenDependencyLockFile.Response\x12\x88\x01\n" +
	"\x15CreateDependencyLocks\x126.terraform1.dependencies.CreateDependencyLocks.Request\x1a7.terraform1.dependencies.CreateDependencyLocks.Response\x12\x85\x01\n" +
	"\x14CloseDependencyLocks\x125.terraform1.dependencies.CloseDependencyLocks.Request\x1a6.terraform1.dependencies.CloseDependencyLocks.Response\x12\xa0\x01\n" +
	"\x1dGetLockedProviderDependencies\x12>.terraform1.dependencies.GetLockedProviderDependencies.Request\x1a?.terraform1.dependencies.GetLockedProviderDependencies.Response\x12\x90\x01\n" +
	"\x18BuildProviderPluginCache\x129.terraform1.dependencies.BuildProviderPluginCache.Request\x1a7.terraform1.dependencies.BuildProviderPluginCache.Event0\x01\x12\x8e\x01\n" +
	"\x17OpenProviderPluginCache\x128.terraform1.dependencies.OpenProviderPluginCache.Request\x1a9.terraform1.dependencies.OpenProviderPluginCache.Response\x12\x91\x01\n" +
	"\x18CloseProviderPluginCache\x129.terraform1.dependencies.CloseProviderPluginCache.Request\x1a:.terraform1.dependencies.CloseProviderPluginCache.Response\x12\x7f\n" +
	"\x12GetCachedProviders\x123.terraform1.dependencies.GetCachedProviders.Request\x1a4.terraform1.dependencies.GetCachedProviders.Response\x12\x82\x01\n" +
	"\x13GetBuiltInProviders\x124.terraform1.dependencies.GetBuiltInProviders.Request\x1a5.terraform1.dependencies.GetBuiltInProviders.Response\x12|\n" +
	"\x11GetProviderSchema\x122.terraform1.dependencies.GetProviderSchema.Request\x1a3.terraform1.dependencies.GetProviderSchema.Responseb\x06proto3"

var (
	file_dependencies_proto_rawDescOnce sync.Once
	file_dependencies_proto_rawDescData []byte
)

func file_dependencies_proto_rawDescGZIP() []byte {
	file_dependencies_proto_rawDescOnce.Do(func() {
		file_dependencies_proto_rawDescData = protoimpl.X.CompressGZIP(unsafe.Slice(unsafe.StringData(file_dependencies_proto_rawDesc), len(file_dependencies_proto_rawDesc)))
	})
	return file_dependencies_proto_rawDescData
}

var file_dependencies_proto_enumTypes = make([]protoimpl.EnumInfo, 4)
var file_dependencies_proto_msgTypes = make([]protoimpl.MessageInfo, 54)
var file_dependencies_proto_goTypes = []any{
	(BuildProviderPluginCache_Event_FetchComplete_AuthResult)(0), // 0: terraform1.dependencies.BuildProviderPluginCache.Event.FetchComplete.AuthResult
	(Schema_NestedBlock_NestingMode)(0),                          // 1: terraform1.dependencies.Schema.NestedBlock.NestingMode
	(Schema_Object_NestingMode)(0),                               // 2: terraform1.dependencies.Schema.Object.NestingMode
	(Schema_DocString_Format)(0),                                 // 3: terraform1.dependencies.Schema.DocString.Format
	(*OpenSourceBundle)(nil),                                     // 4: terraform1.dependencies.OpenSourceBundle
	(*CloseSourceBundle)(nil),                                    // 5: terraform1.dependencies.CloseSourceBundle
	(*OpenDependencyLockFile)(nil),                               // 6: terraform1.dependencies.OpenDependencyLockFile
	(*CreateDependencyLocks)(nil),                                // 7: terraform1.dependencies.CreateDependencyLocks
	(*CloseDependencyLocks)(nil),                                 // 8: terraform1.dependencies.CloseDependencyLocks
	(*GetLockedProviderDependencies)(nil),                        // 9: terraform1.dependencies.GetLockedProviderDependencies
	(*BuildProviderPluginCache)(nil),                             // 10: terraform1.dependencies.BuildProviderPluginCache
	(*OpenProviderPluginCache)(nil),                              // 11: terraform1.dependencies.OpenProviderPluginCache
	(*CloseProviderPluginCache)(nil),                             // 12: terraform1.dependencies.CloseProviderPluginCache
	(*GetCachedProviders)(nil),                                   // 13: terraform1.dependencies.GetCachedProviders
	(*GetBuiltInProviders)(nil),                                  // 14: terraform1.dependencies.GetBuiltInProviders
	(*GetProviderSchema)(nil),                                    // 15: terraform1.dependencies.GetProviderSchema
	(*ProviderSchema)(nil),                                       // 16: terraform1.dependencies.ProviderSchema
	(*ActionSchema)(nil),                                         // 17: terraform1.dependencies.ActionSchema
	(*Schema)(nil),                                               // 18: terraform1.dependencies.Schema
	(*OpenSourceBundle_Request)(nil),                             // 19: terraform1.dependencies.OpenSourceBundle.Request
	(*OpenSourceBundle_Response)(nil),                            // 20: terraform1.dependencies.OpenSourceBundle.Response
	(*CloseSourceBundle_Request)(nil),                            // 21: terraform1.dependencies.CloseSourceBundle.Request
	(*CloseSourceBundle_Response)(nil),                           // 22: terraform1.dependencies.CloseSourceBundle.Response
	(*OpenDependencyLockFile_Request)(nil),                       // 23: terraform1.dependencies.OpenDependencyLockFile.Request
	(*OpenDependencyLockFile_Response)(nil),                      // 24: terraform1.dependencies.OpenDependencyLockFile.Response
	(*CreateDependencyLocks_Request)(nil),                        // 25: terraform1.dependencies.CreateDependencyLocks.Request
	(*CreateDependencyLocks_Response)(nil),                       // 26: terraform1.dependencies.CreateDependencyLocks.Response
	(*CloseDependencyLocks_Request)(nil),                         // 27: terraform1.dependencies.CloseDependencyLocks.Request
	(*CloseDependencyLocks_Response)(nil),                        // 28: terraform1.dependencies.CloseDependencyLocks.Response
	(*GetLockedProviderDependencies_Request)(nil),                // 29: terraform1.dependencies.GetLockedProviderDependencies.Request
	(*GetLockedProviderDependencies_Response)(nil),               // 30: terraform1.dependencies.GetLockedProviderDependencies.Response
	(*BuildProviderPluginCache_Request)(nil),                     // 31: terraform1.dependencies.BuildProviderPluginCache.Request
	(*BuildProviderPluginCache_Event)(nil),                       // 32: terraform1.dependencies.BuildProviderPluginCache.Event
	(*BuildProviderPluginCache_Request_InstallMethod)(nil),       // 33: terraform1.dependencies.BuildProviderPluginCache.Request.InstallMethod
	(*BuildProviderPluginCache_Event_Pending)(nil),               // 34: terraform1.dependencies.BuildProviderPluginCache.Event.Pending
	(*BuildProviderPluginCache_Event_ProviderConstraints)(nil),   // 35: terraform1.dependencies.BuildProviderPluginCache.Event.ProviderConstraints
	(*BuildProviderPluginCache_Event_ProviderVersion)(nil),       // 36: terraform1.dependencies.BuildProviderPluginCache.Event.ProviderVersion
	(*BuildProviderPluginCache_Event_ProviderWarnings)(nil),      // 37: terraform1.dependencies.BuildProviderPluginCache.Event.ProviderWarnings
	(*BuildProviderPluginCache_Event_FetchBegin)(nil),            // 38: terraform1.dependencies.BuildProviderPluginCache.Event.FetchBegin
	(*BuildProviderPluginCache_Event_FetchComplete)(nil),         // 39: terraform1.dependencies.BuildProviderPluginCache.Event.FetchComplete
	(*OpenProviderPluginCache_Request)(nil),                      // 40: terraform1.dependencies.OpenProviderPluginCache.Request
	(*OpenProviderPluginCache_Response)(nil),                     // 41: terraform1.dependencies.OpenProviderPluginCache.Response
	(*CloseProviderPluginCache_Request)(nil),                     // 42: terraform1.dependencies.CloseProviderPluginCache.Request
	(*CloseProviderPluginCache_Response)(nil),                    // 43: terraform1.dependencies.CloseProviderPluginCache.Response
	(*GetCachedProviders_Request)(nil),                           // 44: terraform1.dependencies.GetCachedProviders.Request
	(*GetCachedProviders_Response)(nil),                          // 45: terraform1.dependencies.GetCachedProviders.Response
	(*GetBuiltInProviders_Request)(nil),                          // 46: terraform1.dependencies.GetBuiltInProviders.Request
	(*GetBuiltInProviders_Response)(nil),                         // 47: terraform1.dependencies.GetBuiltInProviders.Response
	(*GetProviderSchema_Request)(nil),                            // 48: terraform1.dependencies.GetProviderSchema.Request
	(*GetProviderSchema_Response)(nil),                           // 49: terraform1.dependencies.GetProviderSchema.Response
	nil,                                                          // 50: terraform1.dependencies.ProviderSchema.ManagedResourceTypesEntry
	nil,                                                          // 51: terraform1.dependencies.ProviderSchema.DataResourceTypesEntry
	nil,                                                          // 52: terraform1.dependencies.ProviderSchema.ActionTypesEntry
	(*Schema_Block)(nil),                                         // 53: terraform1.dependencies.Schema.Block
	(*Schema_Attribute)(nil),                                     // 54: terraform1.dependencies.Schema.Attribute
	(*Schema_NestedBlock)(nil),                                   // 55: terraform1.dependencies.Schema.NestedBlock
	(*Schema_Object)(nil),                                        // 56: terraform1.dependencies.Schema.Object
	(*Schema_DocString)(nil),                                     // 57: terraform1.dependencies.Schema.DocString
	(*terraform1.SourceAddress)(nil),                             // 58: terraform1.SourceAddress
	(*terraform1.Diagnostic)(nil),                                // 59: terraform1.Diagnostic
	(*terraform1.ProviderPackage)(nil),                           // 60: terraform1.ProviderPackage
}
var file_dependencies_proto_depIdxs = []int32{
	18, // 0: terraform1.dependencies.ProviderSchema.provider_config:type_name -> terraform1.dependencies.Schema
	50, // 1: terraform1.dependencies.ProviderSchema.managed_resource_types:type_name -> terraform1.dependencies.ProviderSchema.ManagedResourceTypesEntry
	51, // 2: terraform1.dependencies.ProviderSchema.data_resource_types:type_name -> terraform1.dependencies.ProviderSchema.DataResourceTypesEntry
	52, // 3: terraform1.dependencies.ProviderSchema.action_types:type_name -> terraform1.dependencies.ProviderSchema.ActionTypesEntry
	18, // 4: terraform1.dependencies.ActionSchema.schema:type_name -> terraform1.dependencies.Schema
	53, // 5: terraform1.dependencies.Schema.block:type_name -> terraform1.dependencies.Schema.Block
	58, // 6: terraform1.dependencies.OpenDependencyLockFile.Request.source_address:type_name -> terraform1.SourceAddress
	59, // 7: terraform1.dependencies.OpenDependencyLockFile.Response.diagnostics:type_name -> terraform1.Diagnostic
	60, // 8: terraform1.dependencies.CreateDependencyLocks.Request.provider_selections:type_name -> terraform1.ProviderPackage
	60, // 9: terraform1.dependencies.GetLockedProviderDependencies.Response.selected_providers:type_name -> terraform1.ProviderPackage
	33, // 10: terraform1.dependencies.BuildProviderPluginCache.Request.installation_methods:type_name -> terraform1.dependencies.BuildProviderPluginCache.Request.InstallMethod
	34, // 11: terraform1.dependencies.BuildProviderPluginCache.Event.pending:type_name -> terraform1.dependencies.BuildProviderPluginCache.Event.Pending
	36, // 12: terraform1.dependencies.BuildProviderPluginCache.Event.already_installed:type_name -> terraform1.dependencies.BuildProviderPluginCache.Event.ProviderVersion
	36, // 13: terraform1.dependencies.BuildProviderPluginCache.Event.built_in:type_name -> terraform1.dependencies.BuildProviderPluginCache.Event.ProviderVersion
	35, // 14: terraform1.dependencies.BuildProviderPluginCache.Event.query_begin:type_name -> terraform1.dependencies.BuildProviderPluginCache.Event.ProviderConstraints
	36, // 15: terraform1.dependencies.BuildProviderPluginCache.Event.query_success:type_name -> terraform1.dependencies.BuildProviderPluginCache.Event.ProviderVersion
	37, // 16: terraform1.dependencies.BuildProviderPluginCache.Event.query_warnings:type_name -> terraform1.dependencies.BuildProviderPluginCache.Event.ProviderWarnings
	38, // 17: terraform1.dependencies.BuildProviderPluginCache.Event.fetch_begin:type_name -> terraform1.dependencies.BuildProviderPluginCache.Event.FetchBegin
	39, // 18: terraform1.dependencies.BuildProviderPluginCache.Event.fetch_complete:type_name -> terraform1.dependencies.BuildProviderPluginCache.Event.FetchComplete
	59, // 19: terraform1.dependencies.BuildProviderPluginCache.Event.diagnostic:type_name -> terraform1.Diagnostic
	35, // 20: terraform1.dependencies.BuildProviderPluginCache.Event.Pending.expected:type_name -> terraform1.dependencies.BuildProviderPluginCache.Event.ProviderConstraints
	36, // 21: terraform1.dependencies.BuildProviderPluginCache.Event.FetchBegin.provider_version:type_name -> terraform1.dependencies.BuildProviderPluginCache.Event.ProviderVersion
	36, // 22: terraform1.dependencies.BuildProviderPluginCache.Event.FetchComplete.provider_version:type_name -> terraform1.dependencies.BuildProviderPluginCache.Event.ProviderVersion
	0,  // 23: terraform1.dependencies.BuildProviderPluginCache.Event.FetchComplete.auth_result:type_name -> terraform1.dependencies.BuildProviderPluginCache.Event.FetchComplete.AuthResult
	60, // 24: terraform1.dependencies.GetCachedProviders.Response.available_providers:type_name -> terraform1.ProviderPackage
	60, // 25: terraform1.dependencies.GetBuiltInProviders.Response.available_providers:type_name -> terraform1.ProviderPackage
	16, // 26: terraform1.dependencies.GetProviderSchema.Response.schema:type_name -> terraform1.dependencies.ProviderSchema
	18, // 27: terraform1.dependencies.ProviderSchema.ManagedResourceTypesEntry.value:type_name -> terraform1.dependencies.Schema
	18, // 28: terraform1.dependencies.ProviderSchema.DataResourceTypesEntry.value:type_name -> terraform1.dependencies.Schema
	17, // 29: terraform1.dependencies.ProviderSchema.ActionTypesEntry.value:type_name -> terraform1.dependencies.ActionSchema
	54, // 30: terraform1.dependencies.Schema.Block.attributes:type_name -> terraform1.dependencies.Schema.Attribute
	55, // 31: terraform1.dependencies.Schema.Block.block_types:type_name -> terraform1.dependencies.Schema.NestedBlock
	57, // 32: terraform1.dependencies.Schema.Block.description:type_name -> terraform1.dependencies.Schema.DocString
	56, // 33: terraform1.dependencies.Schema.Attribute.nested_type:type_name -> terraform1.dependencies.Schema.Object
	57, // 34: terraform1.dependencies.Schema.Attribute.description:type_name -> terraform1.dependencies.Schema.DocString
	53, // 35: terraform1.dependencies.Schema.NestedBlock.block:type_name -> terraform1.dependencies.Schema.Block
	1,  // 36: terraform1.dependencies.Schema.NestedBlock.nesting:type_name -> terraform1.dependencies.Schema.NestedBlock.NestingMode
	54, // 37: terraform1.dependencies.Schema.Object.attributes:type_name -> terraform1.dependencies.Schema.Attribute
	2,  // 38: terraform1.dependencies.Schema.Object.nesting:type_name -> terraform1.dependencies.Schema.Object.NestingMode
	3,  // 39: terraform1.dependencies.Schema.DocString.format:type_name -> terraform1.dependencies.Schema.DocString.Format
	19, // 40: terraform1.dependencies.Dependencies.OpenSourceBundle:input_type -> terraform1.dependencies.OpenSourceBundle.Request
	21, // 41: terraform1.dependencies.Dependencies.CloseSourceBundle:input_type -> terraform1.dependencies.CloseSourceBundle.Request
	23, // 42: terraform1.dependencies.Dependencies.OpenDependencyLockFile:input_type -> terraform1.dependencies.OpenDependencyLockFile.Request
	25, // 43: terraform1.dependencies.Dependencies.CreateDependencyLocks:input_type -> terraform1.dependencies.CreateDependencyLocks.Request
	27, // 44: terraform1.dependencies.Dependencies.CloseDependencyLocks:input_type -> terraform1.dependencies.CloseDependencyLocks.Request
	29, // 45: terraform1.dependencies.Dependencies.GetLockedProviderDependencies:input_type -> terraform1.dependencies.GetLockedProviderDependencies.Request
	31, // 46: terraform1.dependencies.Dependencies.BuildProviderPluginCache:input_type -> terraform1.dependencies.BuildProviderPluginCache.Request
	40, // 47: terraform1.dependencies.Dependencies.OpenProviderPluginCache:input_type -> terraform1.dependencies.OpenProviderPluginCache.Request
	42, // 48: terraform1.dependencies.Dependencies.CloseProviderPluginCache:input_type -> terraform1.dependencies.CloseProviderPluginCache.Request
	44, // 49: terraform1.dependencies.Dependencies.GetCachedProviders:input_type -> terraform1.dependencies.GetCachedProviders.Request
	46, // 50: terraform1.dependencies.Dependencies.GetBuiltInProviders:input_type -> terraform1.dependencies.GetBuiltInProviders.Request
	48, // 51: terraform1.dependencies.Dependencies.GetProviderSchema:input_type -> terraform1.dependencies.GetProviderSchema.Request
	20, // 52: terraform1.dependencies.Dependencies.OpenSourceBundle:output_type -> terraform1.dependencies.OpenSourceBundle.Response
	22, // 53: terraform1.dependencies.Dependencies.CloseSourceBundle:output_type -> terraform1.dependencies.CloseSourceBundle.Response
	24, // 54: terraform1.dependencies.Dependencies.OpenDependencyLockFile:output_type -> terraform1.dependencies.OpenDependencyLockFile.Response
	26, // 55: terraform1.dependencies.Dependencies.CreateDependencyLocks:output_type -> terraform1.dependencies.CreateDependencyLocks.Response
	28, // 56: terraform1.dependencies.Dependencies.CloseDependencyLocks:output_type -> terraform1.dependencies.CloseDependencyLocks.Response
	30, // 57: terraform1.dependencies.Dependencies.GetLockedProviderDependencies:output_type -> terraform1.dependencies.GetLockedProviderDependencies.Response
	32, // 58: terraform1.dependencies.Dependencies.BuildProviderPluginCache:output_type -> terraform1.dependencies.BuildProviderPluginCache.Event
	41, // 59: terraform1.dependencies.Dependencies.OpenProviderPluginCache:output_type -> terraform1.dependencies.OpenProviderPluginCache.Response
	43, // 60: terraform1.dependencies.Dependencies.CloseProviderPluginCache:output_type -> terraform1.dependencies.CloseProviderPluginCache.Response
	45, // 61: terraform1.dependencies.Dependencies.GetCachedProviders:output_type -> terraform1.dependencies.GetCachedProviders.Response
	47, // 62: terraform1.dependencies.Dependencies.GetBuiltInProviders:output_type -> terraform1.dependencies.GetBuiltInProviders.Response
	49, // 63: terraform1.dependencies.Dependencies.GetProviderSchema:output_type -> terraform1.dependencies.GetProviderSchema.Response
	52, // [52:64] is the sub-list for method output_type
	40, // [40:52] is the sub-list for method input_type
	40, // [40:40] is the sub-list for extension type_name
	40, // [40:40] is the sub-list for extension extendee
	0,  // [0:40] is the sub-list for field type_name
}

func init() { file_dependencies_proto_init() }
func file_dependencies_proto_init() {
	if File_dependencies_proto != nil {
		return
	}
	file_dependencies_proto_msgTypes[28].OneofWrappers = []any{
		(*BuildProviderPluginCache_Event_Pending_)(nil),
		(*BuildProviderPluginCache_Event_AlreadyInstalled)(nil),
		(*BuildProviderPluginCache_Event_BuiltIn)(nil),
		(*BuildProviderPluginCache_Event_QueryBegin)(nil),
		(*BuildProviderPluginCache_Event_QuerySuccess)(nil),
		(*BuildProviderPluginCache_Event_QueryWarnings)(nil),
		(*BuildProviderPluginCache_Event_FetchBegin_)(nil),
		(*BuildProviderPluginCache_Event_FetchComplete_)(nil),
		(*BuildProviderPluginCache_Event_Diagnostic)(nil),
	}
	file_dependencies_proto_msgTypes[29].OneofWrappers = []any{
		(*BuildProviderPluginCache_Request_InstallMethod_Direct)(nil),
		(*BuildProviderPluginCache_Request_InstallMethod_LocalMirrorDir)(nil),
		(*BuildProviderPluginCache_Request_InstallMethod_NetworkMirrorUrl)(nil),
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: unsafe.Slice(unsafe.StringData(file_dependencies_proto_rawDesc), len(file_dependencies_proto_rawDesc)),
			NumEnums:      4,
			NumMessages:   54,
			NumExtensions: 0,
			NumServices:   1,
		},
		GoTypes:           file_dependencies_proto_goTypes,
		DependencyIndexes: file_dependencies_proto_depIdxs,
		EnumInfos:         file_dependencies_proto_enumTypes,
		MessageInfos:      file_dependencies_proto_msgTypes,
	}.Build()
	File_dependencies_proto = out.File
	file_dependencies_proto_goTypes = nil
	file_dependencies_proto_depIdxs = nil
}
